/**
 * CometChatLocalize component allows you to show text in the locale set by you.
 * Set the locale at the start of the application.
 *
 * @version 1.0.0
 * @author CometChatTeam
 * @copyright © 2022 CometChat Inc.
 *
 */
declare class CometChatLocalize {
    /**Properties and constants */
    static fallbackLanguage: string;
    static locale: any;
    static rtlLanguages: string[];
    static direction: Readonly<{
        ltr: "ltr";
        rtl: "rtl";
    }>;
    static translations: {
        ar: {
            USERS: string;
            CHATS: string;
            GROUPS: string;
            MORE: string;
            MESSAGE_IMAGE: string;
            MESSAGE_FILE: string;
            MESSAGE_VIDEO: string;
            MESSAGE_AUDIO: string;
            CUSTOM_MESSAGE: string;
            MISSED_VOICE_CALL: string;
            MISSED_VIDEO_CALL: string;
            CUSTOM_MESSAGE_POLL: string;
            CUSTOM_MESSAGE_STICKER: string;
            CUSTOM_MESSAGE_DOCUMENT: string;
            CUSTOM_MESSAGE_WHITEBOARD: string;
            ONLINE: string;
            ADMINISTRATOR: string;
            MODERATOR: string;
            PARTICIPANT: string;
            PUBLIC: string;
            PRIVATE: string;
            PASSWORD_PROTECTED: string;
            PRIVACY_AND_SECURITY: string;
            PREFERENCES: string;
            MEMBERS: string;
            TODAY: string;
            YESTERDAY: string;
            SUNDAY: string;
            MONDAY: string;
            TUESDAY: string;
            WEDNESDAY: string;
            THURSDAY: string;
            FRIDAY: string;
            SATURDAY: string;
            TYPING: string;
            IS_TYPING: string;
            CLOSE: string;
            ENTER_GROUP_NAME: string;
            ADD_MEMBERS: string;
            SEND_MESSAGE: string;
            UNBLOCK_USER: string;
            BLOCK_USER: string;
            DELETE_AND_EXIT: string;
            LEAVE_GROUP: string;
            CREATE_GROUP: string;
            SHARED_MEDIA: string;
            VIDEO_CALL: string;
            AUDIO_CALL: string;
            LOADING: string;
            REPLY: string;
            REPLIES: string;
            LAUNCH: string;
            SHARED_COLLABORATIVE_DOCUMENT: string;
            SHARED_COLLABORATIVE_WHITEBOARD: string;
            CREATED_WHITEBOARD: string;
            CREATED_DOCUMENT: string;
            PHOTOS: string;
            VIDEOS: string;
            DOCUMENT: string;
            YOU_DELETED_THIS_MESSAGE: string;
            THIS_MESSAGE_DELETED: string;
            VIEW_ON_YOUTUBE: string;
            SEARCH: string;
            NO_USERS_FOUND: string; /**Override resources */
            ERROR: string;
            NO_GROUPS_FOUND: string;
            NO_CHATS_FOUND: string; /**Add to the original array of translations if language code is not found */
            MEDIA_MESSAGE: string;
            INCOMING_AUDIO_CALL: string;
            INCOMING_VIDEO_CALL: string;
            DECLINE: string;
            ACCEPT: string;
            CALL_INITIATED: string;
            OUTGOING_AUDIO_CALL: string;
            OUTGOING_VIDEO_CALL: string;
            CALL_REJECTED: string;
            REJECTED_CALL: string;
            CALL_ACCEPTED: string;
            JOINED: string;
            LEFT_THE_CALL: string; /**
             * Returns the native language
             * @returns {String} native langauge i.e. en-US
             */
            UNANSWERED_AUDIO_CALL: string;
            UNANSWERED_VIDEO_CALL: string;
            CALL_ENDED: string;
            CALL_CANCELLED: string;
            CALL_BUSY: string;
            CALLING: string;
            ADD: string;
            NO_BANNED_MEMBERS_FOUND: string;
            BANNED_MEMBERS: string;
            NAME: string;
            SCOPE: string;
            UNBAN: string;
            SELECT_GROUP_TYPE: string;
            ENTER_GROUP_PASSWORD: string;
            CREATE: string;
            CREATE_POLL: string;
            QUESTION: string;
            ENTER_YOUR_QUESTION: string;
            OPTIONS: string;
            ENTER_YOUR_OPTION: string;
            ADD_NEW_OPTION: string;
            VIEW_MEMBERS: string;
            DETAILS: string;
            NOTIFICATIONS: string;
            OTHER: string;
            HELP: string;
            REPORT_PROBLEM: string;
            GROUP_MEMBERS: string;
            BAN: string;
            KICK: string;
            PICK_YOUR_EMOJI: string;
            PRIVATE_GROUP: string;
            PROTECTED_GROUP: string;
            VISIT: string;
            ATTACH: string;
            ATTACH_FILE: string;
            ATTACH_VIDEO: string;
            ATTACH_AUDIO: string;
            ATTACH_IMAGE: string;
            COLLABORATE_USING_DOCUMENT: string;
            COLLABORATE_USING_WHITEBOARD: string;
            EMOJI: string;
            ENTER_YOUR_MESSAGE_HERE: string;
            NO_MESSAGES_FOUND: string;
            THREAD: string;
            COLLABORATIVE_DOCUMENT: string;
            COLLABORATIVE_WHITEBOARD: string;
            ADD_REACTION: string;
            NO_STICKERS_FOUND: string;
            REPLY_TO_THREAD: string;
            REPLY_IN_THREAD: string;
            DELETE_MESSAGE: string;
            EDIT_MESSAGE: string;
            OWNER: string;
            CHANGE_SCOPE: string;
            STICKER: string;
            LAST_ACTIVE_AT: string;
            VOICE_CALL: string;
            VIEW_DETAIL: string;
            VOTES: string;
            VOTE: string;
            NO_VOTE: string;
            REACTED: string;
            ADDED: string;
            UNBANNED: string;
            MADE: string;
            CALL_UNANSWERED: string;
            MISSED_AUDIO_CALL: string;
            ENTER_YOUR_PASSWORD: string;
            DOCS: string;
            NO_RECORDS_FOUND: string;
            LIVE_REACTION: string;
            SMILEY_PEOPLE: string;
            ANIMALES_NATURE: string;
            FOOD_DRINK: string;
            ACTIVITY: string;
            TRAVEL_PLACES: string;
            OBJECTS: string;
            SYMBOLS: string;
            FLAGS: string;
            /**
             * Returns rtl or ltr based on the active language
             * @returns {String} the direction of the active langauge
             */
            SENT: string;
            SEEN: string;
            DELIVERED: string;
            TRANSLATE_MESSAGE: string;
            LEFT: string;
            KICKED: string;
            BANNED: string;
            NEW_MESSAGES: string;
            NEW_MESSAGE: string;
            JUMP: string;
            SELECT_VIDEO_SOURCE: string;
            SELECT_INPUT_AUDIO_SOURCE: string;
            SELECT_OUTPUT_AUDIO_SOURCE: string;
            INITIATED_GROUP_CALL: string;
            YOU_INITIATED_GROUP_CALL: string;
            IGNORE: string;
            ON_ANOTHER_CALL: string;
            CREATING: string;
            AVATAR: string;
            GROUP_NAME_BLANK: string;
            GROUP_TYPE_BLANK: string;
            GROUP_PASSWORD_BLANK: string;
            POLL_QUESTION_BLANK: string;
            POLL_OPTION_BLANK: string;
            ONGOING_CALL: string;
            YOU_ALREADY_ONGOING_CALL: string;
            RESIZE: string;
            SETTINGS: string;
            ACTIONS: string;
            VIEW_PROFILE: string;
            SEND_MESSAGE_IN_PRIVATE: string;
            DELETE: string;
            DELETE_CONFIRM: string;
            CANCEL: string;
            LEAVE_CONFIRM: string;
            TRANSFER_CONFIRM: string;
            ADDING: string;
            TRANSFER: string;
            TRANSFERRING: string;
            YES: string;
            NO: string;
            SOMETHING_WRONG: string;
            INVALID_GROUP_NAME: string;
            INVALID_GROUP_TYPE: string;
            INVALID_PASSWORD: string;
            WRONG_PASSWORD: string;
            INVALID_POLL_QUESTION: string;
            INVALID_POLL_OPTION: string;
            SAME_LANGUAGE_MESSAGE: string;
            LEAVE: string;
            CALLS: string;
            CUSTOM_MESSAGE_LOCATION: string;
            OFFLINE: string;
            YOU: string;
            PRIVACY: string;
            BLOCKED_USERS: string;
            "YOU'VE_BLOCKED": string;
            NO_PHOTOS: string;
            NO_VIDEOS: string;
            NO_DOCUMENTS: string;
            JOIN: string;
            DELETE_CONFIRM_MESSAGE: string;
            CHAT_ERROR_MESSAGE: string;
            TRY_AGAIN: string;
            CONFIRM: string;
            UNSAFE_CONTENT: string;
            UNSAFE_CONFIRMATION: string;
            AUDIO_FILE: string;
            SHARED_FILE: string;
            OPEN_DOCUMENT: string;
            OPEN_WHITEBOARD: string;
            PEOPLE_VOTED: string;
            ADD_TO_CHAT: string;
            TAKE_PHOTO: string;
            SET_THE_ANSWERS: string;
            ADD_ANOTHER_ANSWER: string;
            ANSWER: string;
            IN_A_THREAD: string;
            ERROR_GROUP_CREATE: string;
            TRY_AGAIN_LATER: string;
            CONTINUE: string;
            GROUP_NAME_MAX: string;
            PASSWORD_MAX: string;
            GROUP_PASSWORD: string;
            INCORRECT_PASSWORD: string;
            OPEN_WHITEBOARD_TO_DRAW: string;
            CALL_HISTORY: string;
            NO_CALL_HISTORY: string;
            CALL_DETAILS: string;
            CONFERENCE_CALL: string;
            NEW_GROUP: string;
            TRANSFER_OWNERSHIP: string;
            COPY_MESSAGE: string;
            SHARE: string;
            OPEN_DOCUMENT_TO_DRAW: string;
            INFORMATION: string;
            COPY_TEXT: string;
            FORWARD: string;
            TEXT: string;
            INCOMING_CALL: string;
            OUTGOING_CALL: string;
            CALL_MISSED: string;
            NEW_CONVERSATION: string;
            FORWARDING: string;
            READ: string;
            No_RECIPIENT: string;
            RECEIPT_INFORMATION: string;
            MESSAGE: string;
        };
        de: {
            USERS: string;
            CHATS: string;
            GROUPS: string;
            MORE: string;
            MESSAGE_IMAGE: string;
            MESSAGE_FILE: string;
            MESSAGE_VIDEO: string;
            MESSAGE_AUDIO: string;
            CUSTOM_MESSAGE: string;
            MISSED_VOICE_CALL: string;
            MISSED_VIDEO_CALL: string;
            CUSTOM_MESSAGE_POLL: string;
            CUSTOM_MESSAGE_STICKER: string;
            CUSTOM_MESSAGE_DOCUMENT: string;
            CUSTOM_MESSAGE_WHITEBOARD: string;
            ONLINE: string;
            ADMINISTRATOR: string;
            MODERATOR: string;
            PARTICIPANT: string;
            PUBLIC: string;
            PRIVATE: string;
            PASSWORD_PROTECTED: string;
            PRIVACY_AND_SECURITY: string;
            PREFERENCES: string;
            MEMBERS: string;
            TODAY: string;
            YESTERDAY: string;
            SUNDAY: string;
            MONDAY: string;
            TUESDAY: string;
            WEDNESDAY: string;
            THURSDAY: string;
            FRIDAY: string;
            SATURDAY: string;
            TYPING: string;
            IS_TYPING: string;
            CLOSE: string;
            ENTER_GROUP_NAME: string;
            ADD_MEMBERS: string;
            SEND_MESSAGE: string;
            UNBLOCK_USER: string;
            BLOCK_USER: string;
            DELETE_AND_EXIT: string;
            LEAVE_GROUP: string;
            CREATE_GROUP: string;
            SHARED_MEDIA: string;
            VIDEO_CALL: string;
            AUDIO_CALL: string;
            LOADING: string;
            REPLY: string;
            REPLIES: string;
            LAUNCH: string;
            SHARED_COLLABORATIVE_DOCUMENT: string;
            SHARED_COLLABORATIVE_WHITEBOARD: string;
            CREATED_WHITEBOARD: string;
            CREATED_DOCUMENT: string;
            PHOTOS: string;
            VIDEOS: string;
            DOCUMENT: string;
            YOU_DELETED_THIS_MESSAGE: string;
            THIS_MESSAGE_DELETED: string;
            VIEW_ON_YOUTUBE: string;
            SEARCH: string;
            NO_USERS_FOUND: string;
            ERROR: string;
            NO_GROUPS_FOUND: string;
            NO_CHATS_FOUND: string;
            MEDIA_MESSAGE: string;
            INCOMING_AUDIO_CALL: string;
            INCOMING_VIDEO_CALL: string;
            DECLINE: string;
            ACCEPT: string;
            CALL_INITIATED: string;
            OUTGOING_AUDIO_CALL: string;
            OUTGOING_VIDEO_CALL: string;
            CALL_REJECTED: string;
            REJECTED_CALL: string;
            CALL_ACCEPTED: string;
            JOINED: string;
            LEFT_THE_CALL: string;
            UNANSWERED_AUDIO_CALL: string;
            UNANSWERED_VIDEO_CALL: string;
            CALL_ENDED: string;
            CALL_CANCELLED: string;
            CALL_BUSY: string;
            CALLING: string;
            ADD: string;
            NO_BANNED_MEMBERS_FOUND: string;
            BANNED_MEMBERS: string;
            NAME: string;
            SCOPE: string;
            UNBAN: string;
            SELECT_GROUP_TYPE: string;
            ENTER_GROUP_PASSWORD: string;
            CREATE: string;
            CREATE_POLL: string;
            QUESTION: string;
            ENTER_YOUR_QUESTION: string; /**
             * Returns the active language. Return fallback language if translation is not available for the active language
             * @returns {String} active language
             */
            OPTIONS: string;
            ENTER_YOUR_OPTION: string;
            ADD_NEW_OPTION: string;
            VIEW_MEMBERS: string;
            DETAILS: string;
            NOTIFICATIONS: string;
            OTHER: string;
            HELP: string;
            REPORT_PROBLEM: string;
            GROUP_MEMBERS: string;
            BAN: string;
            KICK: string;
            PICK_YOUR_EMOJI: string;
            PRIVATE_GROUP: string;
            PROTECTED_GROUP: string;
            VISIT: string;
            ATTACH: string;
            ATTACH_FILE: string;
            ATTACH_VIDEO: string;
            ATTACH_AUDIO: string;
            ATTACH_IMAGE: string;
            COLLABORATE_USING_DOCUMENT: string;
            COLLABORATE_USING_WHITEBOARD: string;
            EMOJI: string;
            ENTER_YOUR_MESSAGE_HERE: string;
            NO_MESSAGES_FOUND: string;
            THREAD: string;
            COLLABORATIVE_DOCUMENT: string;
            COLLABORATIVE_WHITEBOARD: string;
            ADD_REACTION: string;
            NO_STICKERS_FOUND: string;
            REPLY_TO_THREAD: string;
            REPLY_IN_THREAD: string;
            DELETE_MESSAGE: string;
            EDIT_MESSAGE: string;
            OWNER: string;
            CHANGE_SCOPE: string;
            STICKER: string; /**
             * Returns true if the active language is rtl otherwise return false
             * @returns {Boolean} whether the language is rtl or not
             */
            LAST_ACTIVE_AT: string;
            VOICE_CALL: string;
            VIEW_DETAIL: string;
            VOTES: string;
            VOTE: string;
            NO_VOTE: string;
            REACTED: string;
            ADDED: string;
            UNBANNED: string;
            MADE: string;
            CALL_UNANSWERED: string;
            MISSED_AUDIO_CALL: string;
            ENTER_YOUR_PASSWORD: string;
            DOCS: string;
            NO_RECORDS_FOUND: string;
            LIVE_REACTION: string;
            SMILEY_PEOPLE: string;
            ANIMALES_NATURE: string;
            FOOD_DRINK: string;
            ACTIVITY: string;
            TRAVEL_PLACES: string;
            OBJECTS: string;
            SYMBOLS: string;
            FLAGS: string;
            SENT: string;
            SEEN: string;
            DELIVERED: string;
            TRANSLATE_MESSAGE: string;
            LEFT: string;
            KICKED: string;
            BANNED: string;
            NEW_MESSAGES: string;
            NEW_MESSAGE: string;
            JUMP: string;
            SELECT_VIDEO_SOURCE: string;
            SELECT_INPUT_AUDIO_SOURCE: string;
            SELECT_OUTPUT_AUDIO_SOURCE: string;
            INITIATED_GROUP_CALL: string;
            YOU_INITIATED_GROUP_CALL: string;
            IGNORE: string;
            ON_ANOTHER_CALL: string;
            CREATING: string;
            AVATAR: string;
            GROUP_NAME_BLANK: string;
            GROUP_TYPE_BLANK: string;
            GROUP_PASSWORD_BLANK: string;
            POLL_QUESTION_BLANK: string;
            POLL_OPTION_BLANK: string;
            ONGOING_CALL: string;
            YOU_ALREADY_ONGOING_CALL: string;
            RESIZE: string;
            SETTINGS: string;
            ACTIONS: string;
            VIEW_PROFILE: string;
            SEND_MESSAGE_IN_PRIVATE: string;
            DELETE: string;
            DELETE_CONFIRM: string;
            CANCEL: string;
            LEAVE_CONFIRM: string;
            TRANSFER_CONFIRM: string;
            ADDING: string;
            TRANSFER: string;
            TRANSFERRING: string;
            YES: string;
            NO: string;
            SOMETHING_WRONG: string;
            INVALID_GROUP_NAME: string;
            INVALID_GROUP_TYPE: string;
            INVALID_PASSWORD: string;
            WRONG_PASSWORD: string;
            INVALID_POLL_QUESTION: string;
            INVALID_POLL_OPTION: string;
            SAME_LANGUAGE_MESSAGE: string;
            LEAVE: string;
            CALLS: string;
            CUSTOM_MESSAGE_LOCATION: string;
            OFFLINE: string;
            YOU: string;
            PRIVACY: string;
            BLOCKED_USERS: string;
            "YOU'VE_BLOCKED": string;
            NO_PHOTOS: string;
            NO_VIDEOS: string;
            NO_DOCUMENTS: string;
            JOIN: string;
            DELETE_CONFIRM_MESSAGE: string;
            CHAT_ERROR_MESSAGE: string;
            TRY_AGAIN: string;
            CONFIRM: string;
            UNSAFE_CONTENT: string;
            UNSAFE_CONFIRMATION: string;
            AUDIO_FILE: string;
            SHARED_FILE: string;
            OPEN_DOCUMENT: string;
            OPEN_WHITEBOARD: string;
            PEOPLE_VOTED: string;
            ADD_TO_CHAT: string;
            TAKE_PHOTO: string;
            SET_THE_ANSWERS: string;
            ADD_ANOTHER_ANSWER: string;
            ANSWER: string;
            IN_A_THREAD: string;
            ERROR_GROUP_CREATE: string;
            TRY_AGAIN_LATER: string;
            CONTINUE: string;
            GROUP_NAME_MAX: string;
            PASSWORD_MAX: string;
            GROUP_PASSWORD: string;
            INCORRECT_PASSWORD: string;
            OPEN_WHITEBOARD_TO_DRAW: string;
            CALL_HISTORY: string;
            NO_CALL_HISTORY: string;
            CALL_DETAILS: string;
            CONFERENCE_CALL: string;
            NEW_GROUP: string;
            TRANSFER_OWNERSHIP: string;
            COPY_MESSAGE: string;
            SHARE: string;
            OPEN_DOCUMENT_TO_DRAW: string;
            INFORMATION: string;
            COPY_TEXT: string;
            FORWARD: string;
            TEXT: string;
            INCOMING_CALL: string;
            OUTGOING_CALL: string;
            CALL_MISSED: string;
            NEW_CONVERSATION: string;
            FORWARDING: string;
            READ: string;
            No_RECIPIENT: string;
            RECEIPT_INFORMATION: string;
            MESSAGE: string;
        };
        en: {
            USERS: string;
            CHATS: string;
            GROUPS: string;
            MORE: string;
            MESSAGE_IMAGE: string;
            MESSAGE_FILE: string;
            MESSAGE_VIDEO: string;
            MESSAGE_AUDIO: string;
            CUSTOM_MESSAGE: string;
            MISSED_VOICE_CALL: string;
            MISSED_VIDEO_CALL: string;
            CUSTOM_MESSAGE_POLL: string;
            CUSTOM_MESSAGE_STICKER: string;
            CUSTOM_MESSAGE_DOCUMENT: string;
            CUSTOM_MESSAGE_WHITEBOARD: string;
            ONLINE: string;
            ADMINISTRATOR: string;
            MODERATOR: string;
            PARTICIPANT: string;
            PUBLIC: string;
            PRIVATE: string;
            PASSWORD_PROTECTED: string;
            PRIVACY_AND_SECURITY: string;
            PREFERENCES: string;
            MEMBERS: string;
            TODAY: string;
            YESTERDAY: string;
            SUNDAY: string;
            MONDAY: string;
            TUESDAY: string;
            WEDNESDAY: string;
            THURSDAY: string;
            FRIDAY: string;
            SATURDAY: string;
            TYPING: string;
            IS_TYPING: string;
            CLOSE: string;
            ENTER_GROUP_NAME: string;
            ADD_MEMBERS: string;
            SEND_MESSAGE: string;
            UNBLOCK_USER: string;
            BLOCK_USER: string;
            DELETE_AND_EXIT: string;
            LEAVE_GROUP: string;
            CREATE_GROUP: string;
            SHARED_MEDIA: string;
            VIDEO_CALL: string;
            AUDIO_CALL: string;
            LOADING: string;
            REPLY: string;
            REPLIES: string;
            LAUNCH: string;
            SHARED_COLLABORATIVE_DOCUMENT: string;
            SHARED_COLLABORATIVE_WHITEBOARD: string;
            CREATED_WHITEBOARD: string;
            CREATED_DOCUMENT: string;
            PHOTOS: string;
            VIDEOS: string;
            DOCUMENT: string;
            MESSAGE_IS_DELETED: string;
            THIS_MESSAGE_DELETED: string;
            VIEW_ON_YOUTUBE: string;
            SEARCH: string;
            NO_USERS_FOUND: string; /**Add to the original array of translations if language code is not found */
            ERROR: string;
            NO_GROUPS_FOUND: string;
            NO_CHATS_FOUND: string;
            MEDIA_MESSAGE: string;
            INCOMING_AUDIO_CALL: string;
            INCOMING_VIDEO_CALL: string;
            DECLINE: string;
            ACCEPT: string;
            CALL_INITIATED: string;
            OUTGOING_AUDIO_CALL: string;
            OUTGOING_VIDEO_CALL: string;
            CALL_REJECTED: string;
            REJECTED_CALL: string;
            CALL_ACCEPTED: string;
            JOINED: string;
            LEFT_THE_CALL: string;
            UNANSWERED_AUDIO_CALL: string;
            UNANSWERED_VIDEO_CALL: string;
            CALL_ENDED: string;
            CALL_CANCELLED: string;
            CALL_BUSY: string;
            CALLING: string;
            ADD: string;
            NO_BANNED_MEMBERS_FOUND: string;
            BANNED_MEMBERS: string;
            NAME: string;
            SCOPE: string;
            UNBAN: string;
            SELECT_GROUP_TYPE: string;
            ENTER_GROUP_PASSWORD: string;
            CREATE: string;
            CREATE_POLL: string;
            QUESTION: string;
            ENTER_YOUR_QUESTION: string;
            OPTIONS: string;
            ENTER_YOUR_OPTION: string;
            ADD_NEW_OPTION: string;
            VIEW_MEMBERS: string;
            DETAILS: string; /**
             * Returns the active language. Return fallback language if translation is not available for the active language
             * @returns {String} active language
             */
            NOTIFICATIONS: string;
            OTHER: string;
            HELP: string;
            REPORT_PROBLEM: string;
            GROUP_MEMBERS: string;
            BAN: string;
            KICK: string;
            PICK_YOUR_EMOJI: string;
            PRIVATE_GROUP: string;
            PROTECTED_GROUP: string;
            VISIT: string;
            ATTACH: string;
            ATTACH_FILE: string;
            ATTACH_VIDEO: string;
            ATTACH_AUDIO: string;
            ATTACH_IMAGE: string;
            COLLABORATIVE_DOCUMENT: string;
            COLLABORATIVE_WHITEBOARD: string;
            COLLABORATE_USING_DOCUMENT: string;
            COLLABORATE_USING_WHITEBOARD: string;
            EMOJI: string;
            ENTER_YOUR_MESSAGE_HERE: string;
            NO_MESSAGES_FOUND: string; /**
             * Sets the default lannguage if no language is passed in init method
             */
            THREAD: string;
            ADD_REACTION: string;
            NO_STICKERS_FOUND: string;
            REPLY_TO_THREAD: string;
            REPLY_IN_THREAD: string;
            DELETE_MESSAGE: string;
            EDIT_MESSAGE: string;
            OWNER: string;
            CHANGE_SCOPE: string;
            STICKER: string;
            LAST_ACTIVE_AT: string;
            VOICE_CALL: string;
            VIEW_DETAIL: string;
            VOTES: string;
            VOTE: string;
            NO_VOTE: string;
            REACTED: string;
            ADDED: string;
            UNBANNED: string;
            MADE: string;
            CALL_UNANSWERED: string;
            MISSED_AUDIO_CALL: string;
            ENTER_YOUR_PASSWORD: string;
            DOCS: string;
            NO_RECORDS_FOUND: string;
            LIVE_REACTION: string;
            SMILEY_PEOPLE: string;
            ANIMALES_NATURE: string;
            FOOD_DRINK: string;
            ACTIVITY: string;
            TRAVEL_PLACES: string;
            OBJECTS: string;
            SYMBOLS: string;
            FLAGS: string;
            SENT: string;
            SEEN: string;
            DELIVERED: string;
            TRANSLATE_MESSAGE: string;
            LEFT: string;
            KICKED: string;
            BANNED: string;
            NEW_MESSAGES: string;
            NEW_MESSAGE: string;
            JUMP: string;
            SELECT_VIDEO_SOURCE: string;
            SELECT_INPUT_AUDIO_SOURCE: string;
            SELECT_OUTPUT_AUDIO_SOURCE: string;
            INITIATED_GROUP_CALL: string;
            YOU_INITIATED_GROUP_CALL: string;
            IGNORE: string;
            ON_ANOTHER_CALL: string;
            CREATING: string;
            AVATAR: string;
            ONGOING_CALL: string;
            YOU_ALREADY_ONGOING_CALL: string;
            RESIZE: string;
            SETTINGS: string;
            ACTIONS: string;
            VIEW_PROFILE: string;
            SEND_MESSAGE_IN_PRIVATE: string;
            DELETE: string;
            DELETE_CONFIRM: string;
            CANCEL: string;
            LEAVE_CONFIRM: string;
            TRANSFER_CONFIRM: string;
            ADDING: string;
            TRANSFER: string;
            TRANSFERRING: string;
            YES: string;
            NO: string;
            SOMETHING_WRONG: string;
            INVALID_GROUP_NAME: string;
            INVALID_PASSWORD: string;
            INVALID_GROUP_TYPE: string;
            WRONG_PASSWORD: string;
            INVALID_POLL_QUESTION: string;
            INVALID_POLL_OPTION: string;
            SAME_LANGUAGE_MESSAGE: string;
            LEAVE: string;
            CUSTOM_MESSAGE_LOCATION: string;
            IN_A_THREAD: string;
            CALLS: string;
            OFFLINE: string;
            YOU: string;
            PRIVACY: string;
            BLOCKED_USERS: string;
            "YOU'VE_BLOCKED": string;
            NO_PHOTOS: string;
            NO_VIDEOS: string;
            NO_DOCUMENTS: string;
            JOIN: string;
            DELETE_CONFIRM_MESSAGE: string;
            CHAT_ERROR_MESSAGE: string;
            TRY_AGAIN: string;
            CONFIRM: string;
            UNSAFE_CONTENT: string;
            UNSAFE_CONFIRMATION: string;
            AUDIO_FILE: string;
            SHARED_FILE: string;
            OPEN_DOCUMENT: string;
            OPEN_WHITEBOARD: string;
            PEOPLE_VOTED: string;
            ADD_TO_CHAT: string;
            TAKE_PHOTO: string;
            SET_THE_ANSWERS: string;
            ADD_ANOTHER_ANSWER: string;
            ANSWER: string;
            ERROR_GROUP_CREATE: string;
            TRY_AGAIN_LATER: string;
            CONTINUE: string;
            GROUP_NAME_MAX: string;
            GROUP_PASSWORD_BLANK: string;
            PASSWORD_MAX: string;
            GROUP_PASSWORD: string;
            INCORRECT_PASSWORD: string;
            OPEN_WHITEBOARD_TO_DRAW: string;
            CALL_HISTORY: string;
            NO_CALL_HISTORY: string;
            CALL_DETAILS: string;
            CONFERENCE_CALL: string;
            NEW_GROUP: string;
            TRANSFER_OWNERSHIP: string;
            COPY_MESSAGE: string;
            SHARE: string;
            OPEN_DOCUMENT_TO_DRAW: string;
            INFORMATION: string;
            FORWARD: string;
            COPY_TEXT: string;
            TEXT: string;
            INCOMING_CALL: string;
            OUTGOING_CALL: string;
            CALL_MISSED: string;
            GROUP_NAME_BLANK: string;
            GROUP_TYPE_BLANK: string;
            POLL_QUESTION_BLANK: string;
            POLL_OPTION_BLANK: string;
            NEW_CONVERSATION: string;
            FORWARDING: string;
            READ: string;
            No_RECIPIENT: string;
            RECEIPT_INFORMATION: string;
            MESSAGE: string;
        };
        es: {
            USERS: string;
            CHATS: string;
            GROUPS: string;
            MORE: string;
            MESSAGE_IMAGE: string;
            MESSAGE_FILE: string;
            MESSAGE_VIDEO: string;
            MESSAGE_AUDIO: string;
            CUSTOM_MESSAGE: string;
            MISSED_VOICE_CALL: string;
            MISSED_VIDEO_CALL: string;
            CUSTOM_MESSAGE_POLL: string;
            CUSTOM_MESSAGE_STICKER: string;
            CUSTOM_MESSAGE_DOCUMENT: string;
            CUSTOM_MESSAGE_WHITEBOARD: string;
            ONLINE: string;
            ADMINISTRATOR: string;
            MODERATOR: string;
            PARTICIPANT: string;
            PUBLIC: string;
            PRIVATE: string;
            PASSWORD_PROTECTED: string;
            PRIVACY_AND_SECURITY: string;
            PREFERENCES: string;
            MEMBERS: string;
            TODAY: string;
            YESTERDAY: string;
            SUNDAY: string;
            MONDAY: string;
            TUESDAY: string;
            WEDNESDAY: string;
            THURSDAY: string;
            FRIDAY: string;
            SATURDAY: string;
            TYPING: string;
            IS_TYPING: string;
            CLOSE: string;
            ENTER_GROUP_NAME: string;
            ADD_MEMBERS: string;
            SEND_MESSAGE: string;
            UNBLOCK_USER: string;
            BLOCK_USER: string;
            DELETE_AND_EXIT: string;
            LEAVE_GROUP: string;
            CREATE_GROUP: string;
            SHARED_MEDIA: string;
            VIDEO_CALL: string;
            AUDIO_CALL: string;
            LOADING: string;
            REPLY: string;
            REPLIES: string;
            LAUNCH: string;
            SHARED_COLLABORATIVE_DOCUMENT: string;
            SHARED_COLLABORATIVE_WHITEBOARD: string;
            CREATED_WHITEBOARD: string;
            CREATED_DOCUMENT: string;
            PHOTOS: string;
            VIDEOS: string;
            DOCUMENT: string;
            YOU_DELETED_THIS_MESSAGE: string; /**Override resources */
            THIS_MESSAGE_DELETED: string;
            VIEW_ON_YOUTUBE: string;
            SEARCH: string;
            NO_USERS_FOUND: string;
            ERROR: string;
            NO_GROUPS_FOUND: string;
            NO_CHATS_FOUND: string;
            MEDIA_MESSAGE: string;
            INCOMING_AUDIO_CALL: string;
            INCOMING_VIDEO_CALL: string;
            DECLINE: string;
            ACCEPT: string;
            CALL_INITIATED: string;
            OUTGOING_AUDIO_CALL: string; /**
             * Returns the native language
             * @returns {String} native langauge i.e. en-US
             */
            OUTGOING_VIDEO_CALL: string;
            CALL_REJECTED: string;
            REJECTED_CALL: string;
            CALL_ACCEPTED: string;
            JOINED: string;
            LEFT_THE_CALL: string;
            UNANSWERED_AUDIO_CALL: string;
            UNANSWERED_VIDEO_CALL: string;
            CALL_ENDED: string;
            CALL_CANCELLED: string;
            CALL_BUSY: string;
            CALLING: string;
            ADD: string;
            NO_BANNED_MEMBERS_FOUND: string;
            BANNED_MEMBERS: string;
            NAME: string;
            SCOPE: string;
            UNBAN: string;
            SELECT_GROUP_TYPE: string;
            ENTER_GROUP_PASSWORD: string;
            CREATE: string;
            CREATE_POLL: string;
            QUESTION: string;
            ENTER_YOUR_QUESTION: string;
            OPTIONS: string;
            ENTER_YOUR_OPTION: string;
            ADD_NEW_OPTION: string;
            VIEW_MEMBERS: string;
            DETAILS: string;
            NOTIFICATIONS: string;
            OTHER: string;
            HELP: string;
            REPORT_PROBLEM: string;
            GROUP_MEMBERS: string;
            BAN: string;
            KICK: string;
            PICK_YOUR_EMOJI: string;
            PRIVATE_GROUP: string;
            PROTECTED_GROUP: string;
            VISIT: string;
            ATTACH: string;
            ATTACH_FILE: string;
            ATTACH_VIDEO: string;
            ATTACH_AUDIO: string;
            ATTACH_IMAGE: string;
            COLLABORATE_USING_DOCUMENT: string;
            COLLABORATE_USING_WHITEBOARD: string;
            EMOJI: string;
            ENTER_YOUR_MESSAGE_HERE: string;
            NO_MESSAGES_FOUND: string;
            THREAD: string;
            COLLABORATIVE_DOCUMENT: string;
            COLLABORATIVE_WHITEBOARD: string;
            ADD_REACTION: string;
            NO_STICKERS_FOUND: string;
            REPLY_TO_THREAD: string;
            REPLY_IN_THREAD: string;
            DELETE_MESSAGE: string;
            EDIT_MESSAGE: string;
            OWNER: string;
            CHANGE_SCOPE: string;
            STICKER: string;
            LAST_ACTIVE_AT: string; /**
             * Returns true if the active language is rtl otherwise return false
             * @returns {Boolean} whether the language is rtl or not
             */
            VOICE_CALL: string;
            VIEW_DETAIL: string;
            VOTES: string;
            VOTE: string;
            NO_VOTE: string;
            REACTED: string;
            ADDED: string;
            UNBANNED: string;
            MADE: string;
            CALL_UNANSWERED: string;
            MISSED_AUDIO_CALL: string;
            ENTER_YOUR_PASSWORD: string;
            DOCS: string;
            NO_RECORDS_FOUND: string;
            LIVE_REACTION: string;
            SMILEY_PEOPLE: string;
            ANIMALES_NATURE: string;
            FOOD_DRINK: string;
            ACTIVITY: string;
            TRAVEL_PLACES: string;
            OBJECTS: string;
            SYMBOLS: string;
            FLAGS: string;
            SENT: string;
            SEEN: string;
            DELIVERED: string;
            TRANSLATE_MESSAGE: string;
            LEFT: string;
            KICKED: string;
            BANNED: string;
            NEW_MESSAGES: string;
            NEW_MESSAGE: string;
            JUMP: string;
            SELECT_VIDEO_SOURCE: string;
            SELECT_INPUT_AUDIO_SOURCE: string;
            SELECT_OUTPUT_AUDIO_SOURCE: string;
            INITIATED_GROUP_CALL: string;
            YOU_INITIATED_GROUP_CALL: string;
            IGNORE: string;
            ON_ANOTHER_CALL: string;
            CREATING: string;
            AVATAR: string;
            GROUP_NAME_BLANK: string;
            GROUP_TYPE_BLANK: string;
            GROUP_PASSWORD_BLANK: string;
            POLL_QUESTION_BLANK: string;
            POLL_OPTION_BLANK: string;
            ONGOING_CALL: string;
            YOU_ALREADY_ONGOING_CALL: string;
            RESIZE: string;
            SETTINGS: string;
            ACTIONS: string;
            VIEW_PROFILE: string;
            SEND_MESSAGE_IN_PRIVATE: string;
            DELETE: string;
            DELETE_CONFIRM: string;
            CANCEL: string;
            LEAVE_CONFIRM: string;
            TRANSFER_CONFIRM: string;
            ADDING: string;
            TRANSFER: string;
            TRANSFERRING: string;
            YES: string;
            NO: string;
            SOMETHING_WRONG: string;
            INVALID_GROUP_NAME: string;
            INVALID_GROUP_TYPE: string;
            INVALID_PASSWORD: string;
            WRONG_PASSWORD: string;
            INVALID_POLL_QUESTION: string;
            INVALID_POLL_OPTION: string;
            SAME_LANGUAGE_MESSAGE: string;
            LEAVE: string;
            CALLS: string;
            CUSTOM_MESSAGE_LOCATION: string;
            OFFLINE: string;
            YOU: string;
            PRIVACY: string;
            BLOCKED_USERS: string;
            "YOU'VE_BLOCKED": string;
            NO_PHOTOS: string;
            NO_VIDEOS: string;
            NO_DOCUMENTS: string;
            JOIN: string;
            DELETE_CONFIRM_MESSAGE: string;
            CHAT_ERROR_MESSAGE: string;
            TRY_AGAIN: string;
            CONFIRM: string;
            UNSAFE_CONTENT: string;
            UNSAFE_CONFIRMATION: string;
            AUDIO_FILE: string;
            SHARED_FILE: string;
            OPEN_DOCUMENT: string;
            OPEN_WHITEBOARD: string;
            PEOPLE_VOTED: string;
            ADD_TO_CHAT: string;
            TAKE_PHOTO: string;
            SET_THE_ANSWERS: string;
            ADD_ANOTHER_ANSWER: string;
            ANSWER: string;
            IN_A_THREAD: string;
            ERROR_GROUP_CREATE: string;
            TRY_AGAIN_LATER: string;
            CONTINUE: string;
            GROUP_NAME_MAX: string;
            PASSWORD_MAX: string;
            GROUP_PASSWORD: string;
            INCORRECT_PASSWORD: string;
            OPEN_WHITEBOARD_TO_DRAW: string;
            CALL_HISTORY: string;
            NO_CALL_HISTORY: string;
            CALL_DETAILS: string;
            CONFERENCE_CALL: string;
            NEW_GROUP: string;
            TRANSFER_OWNERSHIP: string;
            COPY_MESSAGE: string;
            SHARE: string;
            OPEN_DOCUMENT_TO_DRAW: string;
            INFORMATION: string;
            COPY_TEXT: string;
            FORWARD: string;
            TEXT: string;
            INCOMING_CALL: string;
            OUTGOING_CALL: string;
            CALL_MISSED: string;
            NEW_CONVERSATION: string;
            FORWARDING: string;
            READ: string;
            No_RECIPIENT: string;
            RECEIPT_INFORMATION: string;
            MESSAGE: string;
        };
        fr: {
            USERS: string;
            CHATS: string;
            GROUPS: string;
            MORE: string;
            MESSAGE_IMAGE: string;
            MESSAGE_FILE: string;
            MESSAGE_VIDEO: string;
            MESSAGE_AUDIO: string;
            CUSTOM_MESSAGE: string;
            MISSED_VOICE_CALL: string;
            MISSED_VIDEO_CALL: string;
            CUSTOM_MESSAGE_POLL: string;
            CUSTOM_MESSAGE_STICKER: string;
            CUSTOM_MESSAGE_DOCUMENT: string;
            CUSTOM_MESSAGE_WHITEBOARD: string;
            ONLINE: string;
            ADMINISTRATOR: string;
            MODERATOR: string;
            PARTICIPANT: string;
            PUBLIC: string;
            PRIVATE: string;
            PASSWORD_PROTECTED: string;
            PRIVACY_AND_SECURITY: string;
            PREFERENCES: string;
            MEMBERS: string;
            TODAY: string;
            /**
             * CometChatLocalize component allows you to show text in the locale set by you.
             * Set the locale at the start of the application.
             *
             * @version 1.0.0
             * @author CometChatTeam
             * @copyright © 2022 CometChat Inc.
             *
             */
            YESTERDAY: string;
            SUNDAY: string;
            MONDAY: string;
            TUESDAY: string;
            WEDNESDAY: string;
            THURSDAY: string;
            FRIDAY: string;
            SATURDAY: string;
            TYPING: string;
            IS_TYPING: string;
            CLOSE: string;
            ENTER_GROUP_NAME: string;
            ADD_MEMBERS: string;
            SEND_MESSAGE: string;
            UNBLOCK_USER: string;
            BLOCK_USER: string;
            DELETE_AND_EXIT: string;
            LEAVE_GROUP: string;
            CREATE_GROUP: string;
            SHARED_MEDIA: string;
            VIDEO_CALL: string;
            AUDIO_CALL: string;
            LOADING: string;
            REPLY: string;
            REPLIES: string;
            LAUNCH: string;
            SHARED_COLLABORATIVE_DOCUMENT: string;
            SHARED_COLLABORATIVE_WHITEBOARD: string;
            CREATED_WHITEBOARD: string;
            CREATED_DOCUMENT: string;
            PHOTOS: string;
            VIDEOS: string;
            DOCUMENT: string;
            YOU_DELETED_THIS_MESSAGE: string;
            THIS_MESSAGE_DELETED: string;
            VIEW_ON_YOUTUBE: string;
            SEARCH: string;
            NO_USERS_FOUND: string;
            ERROR: string;
            NO_GROUPS_FOUND: string;
            NO_CHATS_FOUND: string;
            MEDIA_MESSAGE: string;
            INCOMING_AUDIO_CALL: string;
            INCOMING_VIDEO_CALL: string;
            DECLINE: string;
            ACCEPT: string;
            CALL_INITIATED: string;
            OUTGOING_AUDIO_CALL: string;
            OUTGOING_VIDEO_CALL: string;
            CALL_REJECTED: string;
            REJECTED_CALL: string;
            CALL_ACCEPTED: string;
            JOINED: string;
            LEFT_THE_CALL: string;
            UNANSWERED_AUDIO_CALL: string;
            UNANSWERED_VIDEO_CALL: string;
            CALL_ENDED: string;
            CALL_CANCELLED: string;
            CALL_BUSY: string;
            CALLING: string;
            ADD: string;
            NO_BANNED_MEMBERS_FOUND: string;
            BANNED_MEMBERS: string;
            NAME: string;
            SCOPE: string;
            UNBAN: string;
            SELECT_GROUP_TYPE: string;
            ENTER_GROUP_PASSWORD: string;
            CREATE: string;
            CREATE_POLL: string;
            QUESTION: string;
            ENTER_YOUR_QUESTION: string;
            OPTIONS: string; /**
             * Returns the active language. Return fallback language if translation is not available for the active language
             * @returns {String} active language
             */
            ENTER_YOUR_OPTION: string;
            ADD_NEW_OPTION: string;
            VIEW_MEMBERS: string;
            DETAILS: string;
            NOTIFICATIONS: string;
            OTHER: string;
            HELP: string;
            REPORT_PROBLEM: string;
            GROUP_MEMBERS: string;
            BAN: string;
            KICK: string;
            PICK_YOUR_EMOJI: string;
            /**
             * Set the active language
             * @param {String} language
             */
            PRIVATE_GROUP: string;
            PROTECTED_GROUP: string;
            VISIT: string;
            ATTACH: string;
            ATTACH_FILE: string;
            ATTACH_VIDEO: string;
            ATTACH_AUDIO: string;
            ATTACH_IMAGE: string;
            COLLABORATE_USING_DOCUMENT: string;
            COLLABORATE_USING_WHITEBOARD: string;
            EMOJI: string;
            ENTER_YOUR_MESSAGE_HERE: string;
            NO_MESSAGES_FOUND: string;
            THREAD: string;
            COLLABORATIVE_DOCUMENT: string;
            COLLABORATIVE_WHITEBOARD: string;
            ADD_REACTION: string;
            NO_STICKERS_FOUND: string;
            REPLY_TO_THREAD: string;
            REPLY_IN_THREAD: string;
            DELETE_MESSAGE: string;
            EDIT_MESSAGE: string;
            OWNER: string;
            CHANGE_SCOPE: string;
            STICKER: string;
            LAST_ACTIVE_AT: string;
            VOICE_CALL: string;
            VIEW_DETAIL: string;
            VOTES: string;
            VOTE: string;
            NO_VOTE: string;
            REACTED: string;
            ADDED: string;
            UNBANNED: string;
            MADE: string;
            CALL_UNANSWERED: string;
            MISSED_AUDIO_CALL: string;
            ENTER_YOUR_PASSWORD: string;
            DOCS: string;
            NO_RECORDS_FOUND: string;
            LIVE_REACTION: string;
            SMILEY_PEOPLE: string;
            ANIMALES_NATURE: string;
            FOOD_DRINK: string;
            ACTIVITY: string;
            TRAVEL_PLACES: string;
            OBJECTS: string;
            SYMBOLS: string;
            FLAGS: string;
            SENT: string;
            SEEN: string;
            DELIVERED: string;
            TRANSLATE_MESSAGE: string;
            LEFT: string;
            KICKED: string;
            BANNED: string;
            NEW_MESSAGES: string;
            NEW_MESSAGE: string;
            JUMP: string;
            SELECT_VIDEO_SOURCE: string;
            SELECT_INPUT_AUDIO_SOURCE: string;
            SELECT_OUTPUT_AUDIO_SOURCE: string;
            INITIATED_GROUP_CALL: string;
            YOU_INITIATED_GROUP_CALL: string;
            IGNORE: string;
            ON_ANOTHER_CALL: string;
            CREATING: string;
            AVATAR: string;
            GROUP_NAME_BLANK: string;
            GROUP_TYPE_BLANK: string;
            GROUP_PASSWORD_BLANK: string;
            POLL_QUESTION_BLANK: string;
            POLL_OPTION_BLANK: string;
            ONGOING_CALL: string;
            YOU_ALREADY_ONGOING_CALL: string;
            RESIZE: string;
            SETTINGS: string;
            ACTIONS: string;
            VIEW_PROFILE: string;
            SEND_MESSAGE_IN_PRIVATE: string;
            DELETE: string;
            DELETE_CONFIRM: string;
            CANCEL: string;
            LEAVE_CONFIRM: string;
            TRANSFER_CONFIRM: string;
            ADDING: string;
            TRANSFER: string;
            TRANSFERRING: string;
            YES: string;
            NO: string;
            SOMETHING_WRONG: string;
            INVALID_GROUP_NAME: string;
            INVALID_GROUP_TYPE: string;
            INVALID_PASSWORD: string;
            WRONG_PASSWORD: string;
            INVALID_POLL_QUESTION: string;
            INVALID_POLL_OPTION: string;
            SAME_LANGUAGE_MESSAGE: string;
            LEAVE: string;
            CALLS: string;
            CUSTOM_MESSAGE_LOCATION: string;
            OFFLINE: string;
            YOU: string;
            PRIVACY: string;
            BLOCKED_USERS: string;
            "YOU'VE_BLOCKED": string;
            NO_PHOTOS: string;
            NO_VIDEOS: string;
            NO_DOCUMENTS: string;
            JOIN: string;
            DELETE_CONFIRM_MESSAGE: string;
            CHAT_ERROR_MESSAGE: string;
            TRY_AGAIN: string;
            CONFIRM: string;
            UNSAFE_CONTENT: string;
            UNSAFE_CONFIRMATION: string;
            AUDIO_FILE: string;
            SHARED_FILE: string;
            OPEN_DOCUMENT: string;
            OPEN_WHITEBOARD: string;
            PEOPLE_VOTED: string;
            ADD_TO_CHAT: string;
            TAKE_PHOTO: string;
            SET_THE_ANSWERS: string;
            ADD_ANOTHER_ANSWER: string;
            ANSWER: string;
            IN_A_THREAD: string;
            ERROR_GROUP_CREATE: string;
            TRY_AGAIN_LATER: string;
            CONTINUE: string;
            GROUP_NAME_MAX: string;
            PASSWORD_MAX: string;
            GROUP_PASSWORD: string;
            INCORRECT_PASSWORD: string;
            OPEN_WHITEBOARD_TO_DRAW: string;
            CALL_HISTORY: string;
            NO_CALL_HISTORY: string;
            CALL_DETAILS: string;
            CONFERENCE_CALL: string;
            NEW_GROUP: string;
            TRANSFER_OWNERSHIP: string;
            COPY_MESSAGE: string;
            SHARE: string;
            OPEN_DOCUMENT_TO_DRAW: string;
            INFORMATION: string;
            COPY_TEXT: string;
            FORWARD: string;
            TEXT: string;
            INCOMING_CALL: string;
            OUTGOING_CALL: string;
            CALL_MISSED: string;
            NEW_CONVERSATION: string;
            FORWARDING: string;
            READ: string;
            No_RECIPIENT: string;
            RECEIPT_INFORMATION: string;
            MESSAGE: string;
        };
        hi: {
            USERS: string;
            CHATS: string;
            GROUPS: string;
            MORE: string;
            MESSAGE_IMAGE: string;
            MESSAGE_FILE: string;
            MESSAGE_VIDEO: string;
            MESSAGE_AUDIO: string;
            CUSTOM_MESSAGE: string;
            MISSED_VOICE_CALL: string;
            MISSED_VIDEO_CALL: string;
            CUSTOM_MESSAGE_POLL: string;
            CUSTOM_MESSAGE_STICKER: string;
            CUSTOM_MESSAGE_DOCUMENT: string;
            CUSTOM_MESSAGE_WHITEBOARD: string;
            ONLINE: string;
            ADMINISTRATOR: string;
            MODERATOR: string;
            PARTICIPANT: string;
            PUBLIC: string;
            PRIVATE: string;
            PASSWORD_PROTECTED: string;
            PRIVACY_AND_SECURITY: string;
            PREFERENCES: string;
            MEMBERS: string;
            TODAY: string;
            YESTERDAY: string;
            SUNDAY: string;
            MONDAY: string;
            TUESDAY: string;
            WEDNESDAY: string;
            THURSDAY: string;
            FRIDAY: string;
            SATURDAY: string;
            TYPING: string;
            IS_TYPING: string;
            CLOSE: string;
            ENTER_GROUP_NAME: string;
            ADD_MEMBERS: string;
            SEND_MESSAGE: string;
            UNBLOCK_USER: string;
            BLOCK_USER: string;
            DELETE_AND_EXIT: string;
            LEAVE_GROUP: string;
            CREATE_GROUP: string;
            SHARED_MEDIA: string;
            VIDEO_CALL: string;
            AUDIO_CALL: string;
            LOADING: string;
            REPLY: string;
            REPLIES: string;
            LAUNCH: string;
            SHARED_COLLABORATIVE_DOCUMENT: string;
            SHARED_COLLABORATIVE_WHITEBOARD: string;
            CREATED_WHITEBOARD: string;
            CREATED_DOCUMENT: string;
            PHOTOS: string;
            VIDEOS: string;
            DOCUMENT: string;
            YOU_DELETED_THIS_MESSAGE: string;
            THIS_MESSAGE_DELETED: string;
            VIEW_ON_YOUTUBE: string;
            SEARCH: string; /**Override resources */
            NO_USERS_FOUND: string;
            ERROR: string;
            NO_GROUPS_FOUND: string; /**Add to the original array of translations if language code is not found */
            NO_CHATS_FOUND: string;
            MEDIA_MESSAGE: string;
            INCOMING_AUDIO_CALL: string;
            INCOMING_VIDEO_CALL: string;
            DECLINE: string;
            ACCEPT: string;
            CALL_INITIATED: string;
            OUTGOING_AUDIO_CALL: string;
            OUTGOING_VIDEO_CALL: string;
            CALL_REJECTED: string;
            REJECTED_CALL: string;
            CALL_ACCEPTED: string;
            JOINED: string; /**
             * Returns the native language
             * @returns {String} native langauge i.e. en-US
             */
            LEFT_THE_CALL: string;
            UNANSWERED_AUDIO_CALL: string;
            UNANSWERED_VIDEO_CALL: string;
            CALL_ENDED: string;
            CALL_CANCELLED: string;
            CALL_BUSY: string;
            CALLING: string;
            ADD: string;
            NO_BANNED_MEMBERS_FOUND: string;
            BANNED_MEMBERS: string;
            NAME: string;
            SCOPE: string;
            UNBAN: string;
            SELECT_GROUP_TYPE: string;
            ENTER_GROUP_PASSWORD: string;
            CREATE: string;
            CREATE_POLL: string;
            QUESTION: string;
            ENTER_YOUR_QUESTION: string;
            OPTIONS: string;
            ENTER_YOUR_OPTION: string;
            ADD_NEW_OPTION: string;
            VIEW_MEMBERS: string;
            DETAILS: string;
            NOTIFICATIONS: string;
            OTHER: string;
            HELP: string;
            REPORT_PROBLEM: string;
            GROUP_MEMBERS: string;
            BAN: string;
            KICK: string;
            PICK_YOUR_EMOJI: string;
            PRIVATE_GROUP: string;
            PROTECTED_GROUP: string;
            VISIT: string;
            ATTACH: string;
            ATTACH_FILE: string;
            ATTACH_VIDEO: string;
            ATTACH_AUDIO: string;
            ATTACH_IMAGE: string;
            COLLABORATE_USING_DOCUMENT: string;
            COLLABORATE_USING_WHITEBOARD: string;
            EMOJI: string;
            ENTER_YOUR_MESSAGE_HERE: string;
            NO_MESSAGES_FOUND: string;
            THREAD: string;
            COLLABORATIVE_DOCUMENT: string;
            COLLABORATIVE_WHITEBOARD: string;
            ADD_REACTION: string;
            NO_STICKERS_FOUND: string;
            REPLY_TO_THREAD: string;
            REPLY_IN_THREAD: string;
            DELETE_MESSAGE: string;
            EDIT_MESSAGE: string;
            OWNER: string;
            CHANGE_SCOPE: string;
            STICKER: string;
            LAST_ACTIVE_AT: string;
            VOICE_CALL: string;
            VIEW_DETAIL: string;
            VOTES: string;
            VOTE: string;
            NO_VOTE: string;
            REACTED: string;
            ADDED: string;
            UNBANNED: string;
            MADE: string;
            CALL_UNANSWERED: string;
            MISSED_AUDIO_CALL: string; /**
             * Returns true if the active language is rtl otherwise return false
             * @returns {Boolean} whether the language is rtl or not
             */
            ENTER_YOUR_PASSWORD: string;
            DOCS: string;
            NO_RECORDS_FOUND: string;
            LIVE_REACTION: string;
            SMILEY_PEOPLE: string;
            ANIMALES_NATURE: string;
            FOOD_DRINK: string;
            ACTIVITY: string;
            TRAVEL_PLACES: string;
            OBJECTS: string;
            SYMBOLS: string;
            FLAGS: string;
            SENT: string;
            SEEN: string;
            DELIVERED: string;
            TRANSLATE_MESSAGE: string;
            LEFT: string;
            KICKED: string;
            BANNED: string;
            NEW_MESSAGES: string;
            NEW_MESSAGE: string;
            JUMP: string;
            SELECT_VIDEO_SOURCE: string;
            SELECT_INPUT_AUDIO_SOURCE: string;
            SELECT_OUTPUT_AUDIO_SOURCE: string;
            INITIATED_GROUP_CALL: string;
            YOU_INITIATED_GROUP_CALL: string;
            IGNORE: string;
            ON_ANOTHER_CALL: string;
            CREATING: string;
            AVATAR: string;
            GROUP_NAME_BLANK: string;
            GROUP_TYPE_BLANK: string;
            GROUP_PASSWORD_BLANK: string;
            POLL_QUESTION_BLANK: string;
            POLL_OPTION_BLANK: string;
            ONGOING_CALL: string;
            YOU_ALREADY_ONGOING_CALL: string;
            RESIZE: string;
            SETTINGS: string;
            ACTIONS: string;
            VIEW_PROFILE: string;
            SEND_MESSAGE_IN_PRIVATE: string;
            DELETE: string;
            DELETE_CONFIRM: string;
            CANCEL: string;
            LEAVE_CONFIRM: string;
            TRANSFER_CONFIRM: string;
            ADDING: string;
            TRANSFER: string;
            TRANSFERRING: string;
            YES: string;
            NO: string;
            SOMETHING_WRONG: string;
            INVALID_GROUP_NAME: string;
            INVALID_GROUP_TYPE: string;
            INVALID_PASSWORD: string;
            WRONG_PASSWORD: string;
            INVALID_POLL_QUESTION: string;
            INVALID_POLL_OPTION: string;
            SAME_LANGUAGE_MESSAGE: string;
            LEAVE: string;
            CALLS: string;
            CUSTOM_MESSAGE_LOCATION: string;
            OFFLINE: string;
            YOU: string;
            PRIVACY: string;
            BLOCKED_USERS: string;
            "YOU'VE_BLOCKED": string;
            NO_PHOTOS: string;
            NO_VIDEOS: string;
            NO_DOCUMENTS: string;
            JOIN: string;
            DELETE_CONFIRM_MESSAGE: string;
            CHAT_ERROR_MESSAGE: string;
            TRY_AGAIN: string;
            CONFIRM: string;
            UNSAFE_CONTENT: string;
            UNSAFE_CONFIRMATION: string;
            AUDIO_FILE: string;
            SHARED_FILE: string;
            OPEN_DOCUMENT: string;
            OPEN_WHITEBOARD: string;
            PEOPLE_VOTED: string;
            ADD_TO_CHAT: string;
            TAKE_PHOTO: string;
            SET_THE_ANSWERS: string;
            ADD_ANOTHER_ANSWER: string;
            ANSWER: string;
            IN_A_THREAD: string;
            ERROR_GROUP_CREATE: string;
            TRY_AGAIN_LATER: string;
            CONTINUE: string;
            GROUP_NAME_MAX: string;
            PASSWORD_MAX: string;
            GROUP_PASSWORD: string;
            INCORRECT_PASSWORD: string;
            OPEN_WHITEBOARD_TO_DRAW: string;
            CALL_HISTORY: string;
            NO_CALL_HISTORY: string;
            CALL_DETAILS: string;
            CONFERENCE_CALL: string;
            NEW_GROUP: string;
            TRANSFER_OWNERSHIP: string;
            COPY_MESSAGE: string;
            SHARE: string;
            OPEN_DOCUMENT_TO_DRAW: string;
            INFORMATION: string;
            COPY_TEXT: string;
            FORWARD: string;
            TEXT: string;
            INCOMING_CALL: string;
            OUTGOING_CALL: string;
            CALL_MISSED: string;
            NEW_CONVERSATION: string;
            FORWARDING: string;
            READ: string;
            No_RECIPIENT: string;
            RECEIPT_INFORMATION: string;
            MESSAGE: string;
        };
        ms: {
            USERS: string;
            CHATS: string;
            GROUPS: string;
            MORE: string;
            MESSAGE_IMAGE: string;
            MESSAGE_FILE: string;
            MESSAGE_VIDEO: string;
            MESSAGE_AUDIO: string;
            CUSTOM_MESSAGE: string;
            MISSED_VOICE_CALL: string;
            MISSED_VIDEO_CALL: string;
            CUSTOM_MESSAGE_POLL: string;
            CUSTOM_MESSAGE_STICKER: string;
            CUSTOM_MESSAGE_DOCUMENT: string;
            CUSTOM_MESSAGE_WHITEBOARD: string;
            ONLINE: string;
            ADMINISTRATOR: string;
            MODERATOR: string;
            PARTICIPANT: string;
            PUBLIC: string;
            PRIVATE: string;
            PASSWORD_PROTECTED: string;
            PRIVACY_AND_SECURITY: string;
            PREFERENCES: string;
            MEMBERS: string;
            TODAY: string;
            YESTERDAY: string;
            SUNDAY: string;
            MONDAY: string;
            TUESDAY: string;
            WEDNESDAY: string;
            THURSDAY: string;
            FRIDAY: string;
            SATURDAY: string;
            TYPING: string;
            IS_TYPING: string;
            CLOSE: string;
            ENTER_GROUP_NAME: string;
            ADD_MEMBERS: string;
            SEND_MESSAGE: string;
            UNBLOCK_USER: string;
            BLOCK_USER: string;
            DELETE_AND_EXIT: string;
            LEAVE_GROUP: string;
            CREATE_GROUP: string;
            SHARED_MEDIA: string;
            VIDEO_CALL: string;
            AUDIO_CALL: string;
            LOADING: string;
            REPLY: string;
            REPLIES: string;
            LAUNCH: string;
            SHARED_COLLABORATIVE_DOCUMENT: string;
            SHARED_COLLABORATIVE_WHITEBOARD: string;
            CREATED_WHITEBOARD: string;
            CREATED_DOCUMENT: string;
            PHOTOS: string;
            VIDEOS: string;
            DOCUMENT: string;
            YOU_DELETED_THIS_MESSAGE: string;
            THIS_MESSAGE_DELETED: string;
            VIEW_ON_YOUTUBE: string;
            SEARCH: string;
            NO_USERS_FOUND: string;
            ERROR: string;
            NO_GROUPS_FOUND: string;
            NO_CHATS_FOUND: string;
            MEDIA_MESSAGE: string;
            INCOMING_AUDIO_CALL: string;
            INCOMING_VIDEO_CALL: string;
            DECLINE: string;
            ACCEPT: string;
            CALL_INITIATED: string;
            OUTGOING_AUDIO_CALL: string;
            OUTGOING_VIDEO_CALL: string;
            CALL_REJECTED: string;
            REJECTED_CALL: string;
            CALL_ACCEPTED: string;
            JOINED: string;
            LEFT_THE_CALL: string;
            UNANSWERED_AUDIO_CALL: string;
            UNANSWERED_VIDEO_CALL: string;
            CALL_ENDED: string;
            CALL_CANCELLED: string;
            CALL_BUSY: string; /**
             * Returns the language code
             * @returns {String} language code i.e. en
             */
            CALLING: string;
            ADD: string;
            NO_BANNED_MEMBERS_FOUND: string;
            BANNED_MEMBERS: string;
            NAME: string;
            SCOPE: string;
            UNBAN: string;
            SELECT_GROUP_TYPE: string;
            ENTER_GROUP_PASSWORD: string;
            CREATE: string;
            CREATE_POLL: string;
            QUESTION: string;
            ENTER_YOUR_QUESTION: string;
            OPTIONS: string;
            ENTER_YOUR_OPTION: string;
            ADD_NEW_OPTION: string;
            VIEW_MEMBERS: string;
            DETAILS: string;
            NOTIFICATIONS: string;
            OTHER: string;
            HELP: string;
            REPORT_PROBLEM: string;
            GROUP_MEMBERS: string;
            BAN: string;
            KICK: string;
            PICK_YOUR_EMOJI: string;
            PRIVATE_GROUP: string;
            PROTECTED_GROUP: string; /**
             * Set the active language
             * @param {String} language
             */
            VISIT: string;
            ATTACH: string;
            ATTACH_FILE: string;
            ATTACH_VIDEO: string;
            ATTACH_AUDIO: string;
            ATTACH_IMAGE: string;
            COLLABORATE_USING_DOCUMENT: string;
            COLLABORATE_USING_WHITEBOARD: string;
            EMOJI: string;
            ENTER_YOUR_MESSAGE_HERE: string;
            NO_MESSAGES_FOUND: string;
            THREAD: string;
            COLLABORATIVE_DOCUMENT: string;
            COLLABORATIVE_WHITEBOARD: string;
            ADD_REACTION: string;
            NO_STICKERS_FOUND: string;
            REPLY_TO_THREAD: string;
            REPLY_IN_THREAD: string;
            DELETE_MESSAGE: string;
            EDIT_MESSAGE: string;
            OWNER: string;
            CHANGE_SCOPE: string;
            STICKER: string;
            LAST_ACTIVE_AT: string;
            VOICE_CALL: string;
            VIEW_DETAIL: string;
            VOTES: string;
            /**
             * Returns true if the active language is rtl otherwise return false
             * @returns {Boolean} whether the language is rtl or not
             */
            VOTE: string;
            NO_VOTE: string;
            REACTED: string;
            ADDED: string;
            UNBANNED: string;
            MADE: string;
            CALL_UNANSWERED: string;
            MISSED_AUDIO_CALL: string;
            ENTER_YOUR_PASSWORD: string; /**
             * Returns rtl or ltr based on the active language
             * @returns {String} the direction of the active langauge
             */
            DOCS: string;
            NO_RECORDS_FOUND: string;
            LIVE_REACTION: string;
            SMILEY_PEOPLE: string;
            ANIMALES_NATURE: string;
            FOOD_DRINK: string;
            ACTIVITY: string;
            TRAVEL_PLACES: string;
            OBJECTS: string;
            SYMBOLS: string;
            FLAGS: string;
            SENT: string;
            SEEN: string;
            DELIVERED: string;
            TRANSLATE_MESSAGE: string;
            LEFT: string;
            KICKED: string;
            BANNED: string;
            NEW_MESSAGES: string;
            NEW_MESSAGE: string;
            JUMP: string;
            SELECT_VIDEO_SOURCE: string;
            SELECT_INPUT_AUDIO_SOURCE: string;
            SELECT_OUTPUT_AUDIO_SOURCE: string;
            INITIATED_GROUP_CALL: string;
            YOU_INITIATED_GROUP_CALL: string;
            IGNORE: string;
            ON_ANOTHER_CALL: string;
            CREATING: string;
            AVATAR: string;
            GROUP_NAME_BLANK: string;
            GROUP_TYPE_BLANK: string;
            GROUP_PASSWORD_BLANK: string;
            POLL_QUESTION_BLANK: string;
            POLL_OPTION_BLANK: string;
            ONGOING_CALL: string;
            YOU_ALREADY_ONGOING_CALL: string;
            RESIZE: string;
            SETTINGS: string;
            ACTIONS: string;
            VIEW_PROFILE: string;
            SEND_MESSAGE_IN_PRIVATE: string;
            DELETE: string;
            DELETE_CONFIRM: string;
            CANCEL: string;
            LEAVE_CONFIRM: string;
            TRANSFER_CONFIRM: string;
            ADDING: string;
            TRANSFER: string;
            TRANSFERRING: string;
            YES: string;
            NO: string;
            SOMETHING_WRONG: string;
            INVALID_GROUP_NAME: string;
            INVALID_GROUP_TYPE: string;
            INVALID_PASSWORD: string;
            WRONG_PASSWORD: string;
            INVALID_POLL_QUESTION: string;
            INVALID_POLL_OPTION: string;
            SAME_LANGUAGE_MESSAGE: string;
            LEAVE: string;
            CALLS: string;
            CUSTOM_MESSAGE_LOCATION: string;
            OFFLINE: string;
            YOU: string;
            PRIVACY: string;
            BLOCKED_USERS: string;
            "YOU'VE_BLOCKED": string;
            NO_PHOTOS: string;
            NO_VIDEOS: string;
            NO_DOCUMENTS: string;
            JOIN: string;
            DELETE_CONFIRM_MESSAGE: string;
            CHAT_ERROR_MESSAGE: string;
            TRY_AGAIN: string;
            CONFIRM: string;
            UNSAFE_CONTENT: string;
            UNSAFE_CONFIRMATION: string;
            AUDIO_FILE: string;
            SHARED_FILE: string;
            OPEN_DOCUMENT: string;
            OPEN_WHITEBOARD: string;
            PEOPLE_VOTED: string;
            ADD_TO_CHAT: string;
            TAKE_PHOTO: string;
            SET_THE_ANSWERS: string;
            ADD_ANOTHER_ANSWER: string;
            ANSWER: string;
            IN_A_THREAD: string;
            ERROR_GROUP_CREATE: string;
            TRY_AGAIN_LATER: string;
            CONTINUE: string;
            GROUP_NAME_MAX: string;
            PASSWORD_MAX: string;
            GROUP_PASSWORD: string;
            INCORRECT_PASSWORD: string;
            OPEN_WHITEBOARD_TO_DRAW: string;
            CALL_HISTORY: string;
            NO_CALL_HISTORY: string;
            CALL_DETAILS: string;
            CONFERENCE_CALL: string;
            NEW_GROUP: string;
            TRANSFER_OWNERSHIP: string;
            COPY_MESSAGE: string;
            SHARE: string;
            OPEN_DOCUMENT_TO_DRAW: string;
            INFORMATION: string;
            COPY_TEXT: string;
            FORWARD: string;
            TEXT: string;
            INCOMING_CALL: string;
            OUTGOING_CALL: string;
            CALL_MISSED: string;
            NEW_CONVERSATION: string;
            FORWARDING: string;
            READ: string;
            No_RECIPIENT: string;
            RECEIPT_INFORMATION: string;
            MESSAGE: string;
        };
        pt: {
            USERS: string;
            CHATS: string;
            GROUPS: string;
            MORE: string;
            MESSAGE_IMAGE: string;
            MESSAGE_FILE: string;
            MESSAGE_VIDEO: string;
            MESSAGE_AUDIO: string;
            CUSTOM_MESSAGE: string;
            MISSED_VOICE_CALL: string;
            MISSED_VIDEO_CALL: string;
            CUSTOM_MESSAGE_POLL: string;
            CUSTOM_MESSAGE_STICKER: string;
            CUSTOM_MESSAGE_DOCUMENT: string;
            CUSTOM_MESSAGE_WHITEBOARD: string;
            ONLINE: string;
            ADMINISTRATOR: string;
            MODERATOR: string;
            PARTICIPANT: string;
            PUBLIC: string;
            PRIVATE: string;
            PASSWORD_PROTECTED: string;
            PRIVACY_AND_SECURITY: string;
            PREFERENCES: string;
            MEMBERS: string;
            TODAY: string;
            /**
             * CometChatLocalize component allows you to show text in the locale set by you.
             * Set the locale at the start of the application.
             *
             * @version 1.0.0
             * @author CometChatTeam
             * @copyright © 2022 CometChat Inc.
             *
             */
            YESTERDAY: string;
            SUNDAY: string;
            MONDAY: string;
            TUESDAY: string;
            WEDNESDAY: string;
            THURSDAY: string;
            FRIDAY: string;
            SATURDAY: string;
            TYPING: string;
            IS_TYPING: string;
            CLOSE: string;
            ENTER_GROUP_NAME: string;
            ADD_MEMBERS: string;
            SEND_MESSAGE: string;
            UNBLOCK_USER: string;
            BLOCK_USER: string;
            DELETE_AND_EXIT: string;
            LEAVE_GROUP: string;
            CREATE_GROUP: string;
            SHARED_MEDIA: string;
            VIDEO_CALL: string;
            AUDIO_CALL: string;
            LOADING: string;
            REPLY: string;
            REPLIES: string;
            LAUNCH: string;
            SHARED_COLLABORATIVE_DOCUMENT: string;
            SHARED_COLLABORATIVE_WHITEBOARD: string;
            CREATED_WHITEBOARD: string;
            CREATED_DOCUMENT: string;
            PHOTOS: string;
            VIDEOS: string;
            DOCUMENT: string;
            YOU_DELETED_THIS_MESSAGE: string;
            THIS_MESSAGE_DELETED: string; /**Add to the original array of translations if language code is not found */
            VIEW_ON_YOUTUBE: string;
            SEARCH: string;
            NO_USERS_FOUND: string;
            ERROR: string;
            NO_GROUPS_FOUND: string;
            NO_CHATS_FOUND: string;
            MEDIA_MESSAGE: string;
            INCOMING_AUDIO_CALL: string;
            INCOMING_VIDEO_CALL: string;
            DECLINE: string;
            ACCEPT: string;
            CALL_INITIATED: string;
            /**
             * Returns the native language
             * @returns {String} native langauge i.e. en-US
             */
            OUTGOING_AUDIO_CALL: string;
            OUTGOING_VIDEO_CALL: string;
            CALL_REJECTED: string;
            REJECTED_CALL: string;
            CALL_ACCEPTED: string;
            JOINED: string;
            LEFT_THE_CALL: string;
            UNANSWERED_AUDIO_CALL: string;
            UNANSWERED_VIDEO_CALL: string;
            CALL_ENDED: string;
            CALL_CANCELLED: string;
            CALL_BUSY: string;
            CALLING: string;
            ADD: string;
            NO_BANNED_MEMBERS_FOUND: string;
            BANNED_MEMBERS: string;
            NAME: string;
            SCOPE: string;
            UNBAN: string;
            SELECT_GROUP_TYPE: string;
            ENTER_GROUP_PASSWORD: string;
            CREATE: string;
            CREATE_POLL: string;
            QUESTION: string;
            /**
             * Returns the active language. Return fallback language if translation is not available for the active language
             * @returns {String} active language
             */
            ENTER_YOUR_QUESTION: string;
            OPTIONS: string;
            ENTER_YOUR_OPTION: string;
            ADD_NEW_OPTION: string;
            VIEW_MEMBERS: string;
            DETAILS: string;
            NOTIFICATIONS: string;
            OTHER: string;
            HELP: string;
            REPORT_PROBLEM: string;
            GROUP_MEMBERS: string;
            BAN: string;
            KICK: string;
            PICK_YOUR_EMOJI: string;
            PRIVATE_GROUP: string;
            PROTECTED_GROUP: string;
            VISIT: string;
            ATTACH: string;
            ATTACH_FILE: string;
            ATTACH_VIDEO: string;
            ATTACH_AUDIO: string;
            ATTACH_IMAGE: string;
            COLLABORATE_USING_DOCUMENT: string;
            COLLABORATE_USING_WHITEBOARD: string;
            EMOJI: string;
            ENTER_YOUR_MESSAGE_HERE: string;
            NO_MESSAGES_FOUND: string;
            THREAD: string;
            COLLABORATIVE_DOCUMENT: string;
            COLLABORATIVE_WHITEBOARD: string;
            ADD_REACTION: string;
            NO_STICKERS_FOUND: string;
            REPLY_TO_THREAD: string;
            REPLY_IN_THREAD: string;
            DELETE_MESSAGE: string;
            EDIT_MESSAGE: string;
            OWNER: string;
            CHANGE_SCOPE: string;
            STICKER: string;
            LAST_ACTIVE_AT: string;
            VOICE_CALL: string;
            VIEW_DETAIL: string;
            VOTES: string;
            VOTE: string;
            NO_VOTE: string;
            REACTED: string;
            ADDED: string;
            UNBANNED: string;
            MADE: string;
            CALL_UNANSWERED: string;
            MISSED_AUDIO_CALL: string;
            ENTER_YOUR_PASSWORD: string;
            DOCS: string;
            NO_RECORDS_FOUND: string;
            LIVE_REACTION: string;
            SMILEY_PEOPLE: string;
            ANIMALES_NATURE: string;
            FOOD_DRINK: string;
            ACTIVITY: string;
            TRAVEL_PLACES: string;
            OBJECTS: string;
            SYMBOLS: string;
            FLAGS: string;
            SENT: string;
            SEEN: string;
            DELIVERED: string;
            TRANSLATE_MESSAGE: string;
            LEFT: string;
            KICKED: string;
            BANNED: string;
            NEW_MESSAGES: string;
            NEW_MESSAGE: string;
            JUMP: string;
            SELECT_VIDEO_SOURCE: string;
            SELECT_INPUT_AUDIO_SOURCE: string;
            SELECT_OUTPUT_AUDIO_SOURCE: string;
            INITIATED_GROUP_CALL: string;
            YOU_INITIATED_GROUP_CALL: string;
            IGNORE: string;
            ON_ANOTHER_CALL: string;
            CREATING: string;
            AVATAR: string;
            GROUP_NAME_BLANK: string;
            GROUP_TYPE_BLANK: string;
            GROUP_PASSWORD_BLANK: string;
            POLL_QUESTION_BLANK: string;
            POLL_OPTION_BLANK: string;
            ONGOING_CALL: string;
            YOU_ALREADY_ONGOING_CALL: string;
            RESIZE: string;
            SETTINGS: string;
            ACTIONS: string;
            VIEW_PROFILE: string;
            SEND_MESSAGE_IN_PRIVATE: string;
            DELETE: string;
            DELETE_CONFIRM: string;
            CANCEL: string;
            LEAVE_CONFIRM: string;
            TRANSFER_CONFIRM: string;
            ADDING: string;
            TRANSFER: string;
            TRANSFERRING: string;
            YES: string;
            NO: string;
            SOMETHING_WRONG: string;
            INVALID_GROUP_NAME: string;
            INVALID_GROUP_TYPE: string;
            INVALID_PASSWORD: string;
            WRONG_PASSWORD: string;
            INVALID_POLL_QUESTION: string;
            INVALID_POLL_OPTION: string;
            SAME_LANGUAGE_MESSAGE: string;
            LEAVE: string;
            CALLS: string;
            CUSTOM_MESSAGE_LOCATION: string;
            OFFLINE: string;
            YOU: string;
            PRIVACY: string;
            BLOCKED_USERS: string;
            "YOU'VE_BLOCKED": string;
            NO_PHOTOS: string;
            NO_VIDEOS: string;
            NO_DOCUMENTS: string;
            JOIN: string;
            DELETE_CONFIRM_MESSAGE: string;
            CHAT_ERROR_MESSAGE: string;
            TRY_AGAIN: string;
            CONFIRM: string;
            UNSAFE_CONTENT: string;
            UNSAFE_CONFIRMATION: string;
            AUDIO_FILE: string;
            SHARED_FILE: string;
            OPEN_DOCUMENT: string;
            OPEN_WHITEBOARD: string;
            PEOPLE_VOTED: string;
            ADD_TO_CHAT: string;
            TAKE_PHOTO: string;
            SET_THE_ANSWERS: string;
            ADD_ANOTHER_ANSWER: string;
            ANSWER: string;
            IN_A_THREAD: string;
            ERROR_GROUP_CREATE: string;
            TRY_AGAIN_LATER: string;
            CONTINUE: string;
            GROUP_NAME_MAX: string;
            PASSWORD_MAX: string;
            GROUP_PASSWORD: string;
            INCORRECT_PASSWORD: string;
            OPEN_WHITEBOARD_TO_DRAW: string;
            CALL_HISTORY: string;
            NO_CALL_HISTORY: string;
            CALL_DETAILS: string;
            CONFERENCE_CALL: string;
            NEW_GROUP: string;
            TRANSFER_OWNERSHIP: string;
            COPY_MESSAGE: string;
            SHARE: string;
            OPEN_DOCUMENT_TO_DRAW: string;
            INFORMATION: string;
            COPY_TEXT: string;
            FORWARD: string;
            TEXT: string;
            INCOMING_CALL: string;
            OUTGOING_CALL: string;
            CALL_MISSED: string;
            NEW_CONVERSATION: string;
            FORWARDING: string;
            READ: string;
            No_RECIPIENT: string;
            RECEIPT_INFORMATION: string;
            MESSAGE: string;
        };
        ru: {
            USERS: string;
            CHATS: string;
            GROUPS: string;
            MORE: string;
            MESSAGE_IMAGE: string;
            MESSAGE_FILE: string;
            MESSAGE_VIDEO: string;
            MESSAGE_AUDIO: string;
            CUSTOM_MESSAGE: string;
            MISSED_VOICE_CALL: string;
            MISSED_VIDEO_CALL: string;
            CUSTOM_MESSAGE_POLL: string;
            CUSTOM_MESSAGE_STICKER: string;
            CUSTOM_MESSAGE_DOCUMENT: string;
            CUSTOM_MESSAGE_WHITEBOARD: string;
            ONLINE: string;
            ADMINISTRATOR: string;
            MODERATOR: string;
            PARTICIPANT: string;
            PUBLIC: string;
            PRIVATE: string;
            PASSWORD_PROTECTED: string;
            PRIVACY_AND_SECURITY: string;
            PREFERENCES: string;
            MEMBERS: string;
            TODAY: string;
            YESTERDAY: string;
            SUNDAY: string;
            MONDAY: string;
            TUESDAY: string;
            WEDNESDAY: string;
            THURSDAY: string;
            FRIDAY: string;
            SATURDAY: string;
            TYPING: string;
            IS_TYPING: string;
            CLOSE: string;
            ENTER_GROUP_NAME: string;
            ADD_MEMBERS: string;
            SEND_MESSAGE: string;
            UNBLOCK_USER: string;
            BLOCK_USER: string;
            DELETE_AND_EXIT: string;
            LEAVE_GROUP: string;
            CREATE_GROUP: string;
            SHARED_MEDIA: string;
            VIDEO_CALL: string;
            AUDIO_CALL: string;
            LOADING: string;
            REPLY: string;
            REPLIES: string;
            LAUNCH: string;
            SHARED_COLLABORATIVE_DOCUMENT: string;
            SHARED_COLLABORATIVE_WHITEBOARD: string;
            CREATED_WHITEBOARD: string;
            CREATED_DOCUMENT: string;
            PHOTOS: string;
            VIDEOS: string;
            DOCUMENT: string;
            YOU_DELETED_THIS_MESSAGE: string; /**Override resources */
            THIS_MESSAGE_DELETED: string;
            VIEW_ON_YOUTUBE: string;
            SEARCH: string;
            NO_USERS_FOUND: string;
            ERROR: string;
            NO_GROUPS_FOUND: string;
            NO_CHATS_FOUND: string;
            MEDIA_MESSAGE: string;
            INCOMING_AUDIO_CALL: string;
            INCOMING_VIDEO_CALL: string;
            DECLINE: string;
            ACCEPT: string;
            CALL_INITIATED: string;
            OUTGOING_AUDIO_CALL: string;
            OUTGOING_VIDEO_CALL: string;
            CALL_REJECTED: string;
            REJECTED_CALL: string;
            CALL_ACCEPTED: string;
            JOINED: string;
            LEFT_THE_CALL: string;
            UNANSWERED_AUDIO_CALL: string;
            UNANSWERED_VIDEO_CALL: string;
            CALL_ENDED: string;
            CALL_CANCELLED: string;
            CALL_BUSY: string;
            CALLING: string;
            ADD: string;
            NO_BANNED_MEMBERS_FOUND: string;
            BANNED_MEMBERS: string;
            NAME: string;
            SCOPE: string;
            UNBAN: string;
            SELECT_GROUP_TYPE: string;
            ENTER_GROUP_PASSWORD: string;
            CREATE: string;
            CREATE_POLL: string;
            QUESTION: string;
            ENTER_YOUR_QUESTION: string;
            OPTIONS: string;
            ENTER_YOUR_OPTION: string;
            ADD_NEW_OPTION: string;
            VIEW_MEMBERS: string;
            DETAILS: string;
            NOTIFICATIONS: string;
            OTHER: string;
            HELP: string;
            REPORT_PROBLEM: string;
            GROUP_MEMBERS: string;
            BAN: string;
            KICK: string;
            PICK_YOUR_EMOJI: string;
            PRIVATE_GROUP: string;
            PROTECTED_GROUP: string;
            VISIT: string;
            ATTACH: string;
            ATTACH_FILE: string;
            ATTACH_VIDEO: string;
            ATTACH_AUDIO: string;
            ATTACH_IMAGE: string;
            COLLABORATE_USING_DOCUMENT: string;
            COLLABORATE_USING_WHITEBOARD: string;
            EMOJI: string;
            ENTER_YOUR_MESSAGE_HERE: string;
            NO_MESSAGES_FOUND: string;
            THREAD: string;
            COLLABORATIVE_DOCUMENT: string;
            COLLABORATIVE_WHITEBOARD: string;
            ADD_REACTION: string;
            NO_STICKERS_FOUND: string;
            REPLY_TO_THREAD: string;
            REPLY_IN_THREAD: string;
            DELETE_MESSAGE: string;
            EDIT_MESSAGE: string;
            OWNER: string;
            CHANGE_SCOPE: string;
            STICKER: string;
            LAST_ACTIVE_AT: string;
            VOICE_CALL: string;
            VIEW_DETAIL: string;
            VOTES: string;
            VOTE: string;
            NO_VOTE: string;
            REACTED: string;
            ADDED: string;
            UNBANNED: string;
            MADE: string;
            CALL_UNANSWERED: string;
            MISSED_AUDIO_CALL: string;
            ENTER_YOUR_PASSWORD: string;
            DOCS: string;
            NO_RECORDS_FOUND: string;
            LIVE_REACTION: string;
            SMILEY_PEOPLE: string;
            ANIMALES_NATURE: string;
            FOOD_DRINK: string;
            ACTIVITY: string;
            TRAVEL_PLACES: string;
            OBJECTS: string;
            SYMBOLS: string;
            FLAGS: string;
            SENT: string;
            SEEN: string;
            DELIVERED: string;
            TRANSLATE_MESSAGE: string;
            LEFT: string;
            KICKED: string;
            BANNED: string;
            NEW_MESSAGES: string;
            NEW_MESSAGE: string;
            JUMP: string;
            SELECT_VIDEO_SOURCE: string;
            SELECT_INPUT_AUDIO_SOURCE: string;
            SELECT_OUTPUT_AUDIO_SOURCE: string;
            INITIATED_GROUP_CALL: string;
            YOU_INITIATED_GROUP_CALL: string;
            IGNORE: string;
            ON_ANOTHER_CALL: string;
            CREATING: string;
            AVATAR: string;
            GROUP_NAME_BLANK: string;
            GROUP_TYPE_BLANK: string;
            GROUP_PASSWORD_BLANK: string;
            POLL_QUESTION_BLANK: string;
            POLL_OPTION_BLANK: string;
            ONGOING_CALL: string;
            YOU_ALREADY_ONGOING_CALL: string;
            RESIZE: string;
            SETTINGS: string;
            ACTIONS: string;
            VIEW_PROFILE: string;
            SEND_MESSAGE_IN_PRIVATE: string;
            DELETE: string;
            DELETE_CONFIRM: string;
            CANCEL: string;
            LEAVE_CONFIRM: string;
            TRANSFER_CONFIRM: string;
            ADDING: string;
            TRANSFER: string;
            TRANSFERRING: string;
            YES: string;
            NO: string;
            SOMETHING_WRONG: string;
            INVALID_GROUP_NAME: string;
            INVALID_GROUP_TYPE: string;
            INVALID_PASSWORD: string;
            WRONG_PASSWORD: string;
            INVALID_POLL_QUESTION: string;
            INVALID_POLL_OPTION: string;
            SAME_LANGUAGE_MESSAGE: string;
            LEAVE: string;
            CALLS: string;
            CUSTOM_MESSAGE_LOCATION: string;
            OFFLINE: string;
            YOU: string;
            PRIVACY: string;
            BLOCKED_USERS: string;
            "YOU'VE_BLOCKED": string;
            NO_PHOTOS: string;
            NO_VIDEOS: string;
            NO_DOCUMENTS: string;
            JOIN: string;
            DELETE_CONFIRM_MESSAGE: string;
            CHAT_ERROR_MESSAGE: string;
            TRY_AGAIN: string;
            CONFIRM: string;
            UNSAFE_CONTENT: string;
            UNSAFE_CONFIRMATION: string;
            AUDIO_FILE: string;
            SHARED_FILE: string;
            OPEN_DOCUMENT: string;
            OPEN_WHITEBOARD: string;
            PEOPLE_VOTED: string;
            ADD_TO_CHAT: string;
            TAKE_PHOTO: string;
            SET_THE_ANSWERS: string;
            ADD_ANOTHER_ANSWER: string;
            ANSWER: string;
            IN_A_THREAD: string;
            ERROR_GROUP_CREATE: string;
            TRY_AGAIN_LATER: string;
            CONTINUE: string;
            GROUP_NAME_MAX: string;
            PASSWORD_MAX: string;
            GROUP_PASSWORD: string;
            INCORRECT_PASSWORD: string;
            OPEN_WHITEBOARD_TO_DRAW: string;
            CALL_HISTORY: string;
            NO_CALL_HISTORY: string;
            CALL_DETAILS: string;
            CONFERENCE_CALL: string;
            NEW_GROUP: string;
            TRANSFER_OWNERSHIP: string;
            COPY_MESSAGE: string;
            SHARE: string;
            OPEN_DOCUMENT_TO_DRAW: string;
            INFORMATION: string;
            COPY_TEXT: string;
            FORWARD: string;
            TEXT: string;
            INCOMING_CALL: string;
            OUTGOING_CALL: string;
            CALL_MISSED: string;
            NEW_CONVERSATION: string;
            FORWARDING: string;
            READ: string;
            No_RECIPIENT: string;
            RECEIPT_INFORMATION: string;
            MESSAGE: string;
        };
        zh: {
            USERS: string;
            CHATS: string;
            GROUPS: string;
            MORE: string;
            MESSAGE_IMAGE: string;
            MESSAGE_FILE: string;
            MESSAGE_VIDEO: string;
            MESSAGE_AUDIO: string;
            CUSTOM_MESSAGE: string;
            MISSED_VOICE_CALL: string;
            MISSED_VIDEO_CALL: string;
            CUSTOM_MESSAGE_POLL: string;
            CUSTOM_MESSAGE_STICKER: string;
            CUSTOM_MESSAGE_DOCUMENT: string;
            CUSTOM_MESSAGE_WHITEBOARD: string;
            ONLINE: string;
            ADMINISTRATOR: string;
            MODERATOR: string;
            PARTICIPANT: string;
            PUBLIC: string;
            PRIVATE: string;
            PASSWORD_PROTECTED: string;
            PRIVACY_AND_SECURITY: string;
            PREFERENCES: string;
            MEMBERS: string;
            TODAY: string;
            YESTERDAY: string;
            SUNDAY: string;
            MONDAY: string;
            TUESDAY: string;
            WEDNESDAY: string;
            THURSDAY: string;
            FRIDAY: string;
            SATURDAY: string;
            TYPING: string;
            IS_TYPING: string;
            CLOSE: string;
            ENTER_GROUP_NAME: string;
            ADD_MEMBERS: string;
            SEND_MESSAGE: string;
            UNBLOCK_USER: string;
            BLOCK_USER: string;
            DELETE_AND_EXIT: string;
            LEAVE_GROUP: string;
            CREATE_GROUP: string;
            SHARED_MEDIA: string;
            VIDEO_CALL: string;
            AUDIO_CALL: string;
            LOADING: string;
            REPLY: string;
            REPLIES: string;
            LAUNCH: string;
            SHARED_COLLABORATIVE_DOCUMENT: string;
            SHARED_COLLABORATIVE_WHITEBOARD: string;
            CREATED_WHITEBOARD: string;
            CREATED_DOCUMENT: string;
            PHOTOS: string;
            VIDEOS: string;
            DOCUMENT: string;
            YOU_DELETED_THIS_MESSAGE: string;
            THIS_MESSAGE_DELETED: string;
            VIEW_ON_YOUTUBE: string;
            SEARCH: string;
            NO_USERS_FOUND: string;
            ERROR: string;
            NO_GROUPS_FOUND: string;
            NO_CHATS_FOUND: string;
            MEDIA_MESSAGE: string;
            INCOMING_AUDIO_CALL: string;
            INCOMING_VIDEO_CALL: string;
            DECLINE: string;
            ACCEPT: string;
            CALL_INITIATED: string;
            OUTGOING_AUDIO_CALL: string;
            OUTGOING_VIDEO_CALL: string;
            CALL_REJECTED: string;
            REJECTED_CALL: string;
            CALL_ACCEPTED: string;
            JOINED: string;
            LEFT_THE_CALL: string;
            UNANSWERED_AUDIO_CALL: string;
            UNANSWERED_VIDEO_CALL: string;
            CALL_ENDED: string;
            CALL_CANCELLED: string; /**Add to the original array of translations if language code is not found */
            CALL_BUSY: string;
            CALLING: string;
            ADD: string;
            NO_BANNED_MEMBERS_FOUND: string;
            BANNED_MEMBERS: string;
            NAME: string;
            SCOPE: string;
            UNBAN: string;
            SELECT_GROUP_TYPE: string;
            ENTER_GROUP_PASSWORD: string;
            CREATE: string;
            CREATE_POLL: string;
            QUESTION: string;
            ENTER_YOUR_QUESTION: string;
            OPTIONS: string;
            ENTER_YOUR_OPTION: string;
            ADD_NEW_OPTION: string;
            VIEW_MEMBERS: string; /**
             * Returns the native language
             * @returns {String} native langauge i.e. en-US
             */
            DETAILS: string;
            NOTIFICATIONS: string;
            OTHER: string;
            HELP: string;
            REPORT_PROBLEM: string;
            GROUP_MEMBERS: string;
            BAN: string;
            KICK: string;
            PICK_YOUR_EMOJI: string;
            PRIVATE_GROUP: string;
            PROTECTED_GROUP: string;
            VISIT: string;
            ATTACH: string;
            ATTACH_FILE: string;
            ATTACH_VIDEO: string;
            ATTACH_AUDIO: string;
            ATTACH_IMAGE: string;
            COLLABORATE_USING_DOCUMENT: string;
            COLLABORATE_USING_WHITEBOARD: string;
            EMOJI: string;
            ENTER_YOUR_MESSAGE_HERE: string;
            NO_MESSAGES_FOUND: string;
            THREAD: string;
            COLLABORATIVE_DOCUMENT: string;
            COLLABORATIVE_WHITEBOARD: string;
            ADD_REACTION: string;
            NO_STICKERS_FOUND: string;
            REPLY_TO_THREAD: string;
            REPLY_IN_THREAD: string;
            DELETE_MESSAGE: string;
            EDIT_MESSAGE: string;
            OWNER: string;
            CHANGE_SCOPE: string;
            STICKER: string;
            LAST_ACTIVE_AT: string;
            VOICE_CALL: string;
            VIEW_DETAIL: string;
            VOTES: string;
            VOTE: string;
            NO_VOTE: string;
            REACTED: string;
            ADDED: string;
            UNBANNED: string;
            MADE: string;
            CALL_UNANSWERED: string;
            MISSED_AUDIO_CALL: string;
            ENTER_YOUR_PASSWORD: string;
            DOCS: string;
            NO_RECORDS_FOUND: string;
            LIVE_REACTION: string;
            SMILEY_PEOPLE: string;
            ANIMALES_NATURE: string;
            FOOD_DRINK: string; /**
             * Set the active language
             * @param {String} language
             */
            ACTIVITY: string;
            TRAVEL_PLACES: string;
            OBJECTS: string;
            SYMBOLS: string;
            FLAGS: string;
            SENT: string;
            SEEN: string;
            DELIVERED: string;
            TRANSLATE_MESSAGE: string;
            LEFT: string;
            KICKED: string;
            BANNED: string;
            NEW_MESSAGES: string;
            NEW_MESSAGE: string;
            JUMP: string;
            SELECT_VIDEO_SOURCE: string;
            SELECT_INPUT_AUDIO_SOURCE: string;
            SELECT_OUTPUT_AUDIO_SOURCE: string;
            INITIATED_GROUP_CALL: string;
            YOU_INITIATED_GROUP_CALL: string;
            IGNORE: string;
            ON_ANOTHER_CALL: string;
            CREATING: string;
            AVATAR: string;
            GROUP_NAME_BLANK: string;
            GROUP_TYPE_BLANK: string;
            GROUP_PASSWORD_BLANK: string;
            POLL_QUESTION_BLANK: string;
            POLL_OPTION_BLANK: string;
            ONGOING_CALL: string;
            YOU_ALREADY_ONGOING_CALL: string;
            RESIZE: string;
            SETTINGS: string;
            ACTIONS: string;
            VIEW_PROFILE: string;
            SEND_MESSAGE_IN_PRIVATE: string;
            DELETE: string;
            DELETE_CONFIRM: string;
            CANCEL: string;
            LEAVE_CONFIRM: string; /**
             * Returns true if the active language is rtl otherwise return false
             * @returns {Boolean} whether the language is rtl or not
             */
            TRANSFER_CONFIRM: string;
            ADDING: string;
            TRANSFER: string;
            TRANSFERRING: string;
            YES: string;
            NO: string;
            SOMETHING_WRONG: string;
            INVALID_GROUP_NAME: string;
            INVALID_GROUP_TYPE: string;
            INVALID_PASSWORD: string;
            WRONG_PASSWORD: string;
            INVALID_POLL_QUESTION: string;
            INVALID_POLL_OPTION: string;
            SAME_LANGUAGE_MESSAGE: string;
            LEAVE: string;
            CALLS: string;
            CUSTOM_MESSAGE_LOCATION: string;
            OFFLINE: string;
            YOU: string;
            PRIVACY: string;
            BLOCKED_USERS: string;
            "YOU'VE_BLOCKED": string;
            NO_PHOTOS: string;
            NO_VIDEOS: string;
            NO_DOCUMENTS: string;
            JOIN: string;
            DELETE_CONFIRM_MESSAGE: string;
            CHAT_ERROR_MESSAGE: string;
            TRY_AGAIN: string;
            CONFIRM: string;
            UNSAFE_CONTENT: string;
            UNSAFE_CONFIRMATION: string;
            AUDIO_FILE: string;
            SHARED_FILE: string;
            OPEN_DOCUMENT: string;
            OPEN_WHITEBOARD: string;
            PEOPLE_VOTED: string;
            ADD_TO_CHAT: string;
            TAKE_PHOTO: string;
            SET_THE_ANSWERS: string;
            ADD_ANOTHER_ANSWER: string;
            ANSWER: string;
            IN_A_THREAD: string;
            ERROR_GROUP_CREATE: string;
            TRY_AGAIN_LATER: string;
            CONTINUE: string;
            GROUP_NAME_MAX: string;
            PASSWORD_MAX: string;
            GROUP_PASSWORD: string;
            INCORRECT_PASSWORD: string;
            OPEN_WHITEBOARD_TO_DRAW: string;
            CALL_HISTORY: string;
            NO_CALL_HISTORY: string;
            CALL_DETAILS: string;
            CONFERENCE_CALL: string;
            NEW_GROUP: string;
            TRANSFER_OWNERSHIP: string;
            COPY_MESSAGE: string;
            SHARE: string;
            OPEN_DOCUMENT_TO_DRAW: string;
            INFORMATION: string;
            COPY_TEXT: string;
            FORWARD: string;
            TEXT: string;
            INCOMING_CALL: string;
            OUTGOING_CALL: string;
            CALL_MISSED: string;
            NEW_CONVERSATION: string;
            FORWARDING: string;
            READ: string;
            No_RECIPIENT: string;
            RECEIPT_INFORMATION: string;
            MESSAGE: string;
        };
        "zh-tw": {
            USERS: string;
            CHATS: string;
            GROUPS: string;
            MORE: string;
            MESSAGE_IMAGE: string;
            MESSAGE_FILE: string;
            MESSAGE_VIDEO: string;
            MESSAGE_AUDIO: string;
            CUSTOM_MESSAGE: string;
            MISSED_VOICE_CALL: string;
            MISSED_VIDEO_CALL: string;
            CUSTOM_MESSAGE_POLL: string;
            CUSTOM_MESSAGE_STICKER: string;
            CUSTOM_MESSAGE_DOCUMENT: string;
            CUSTOM_MESSAGE_WHITEBOARD: string;
            ONLINE: string;
            ADMINISTRATOR: string;
            MODERATOR: string;
            PARTICIPANT: string;
            PUBLIC: string;
            PRIVATE: string;
            PASSWORD_PROTECTED: string;
            PRIVACY_AND_SECURITY: string;
            PREFERENCES: string;
            MEMBERS: string;
            TODAY: string;
            YESTERDAY: string;
            TYPING: string;
            IS_TYPING: string;
            CLOSE: string;
            ENTER_GROUP_NAME: string;
            ADD_MEMBERS: string;
            SEND_MESSAGE: string;
            UNBLOCK_USER: string;
            BLOCK_USER: string;
            DELETE_AND_EXIT: string;
            LEAVE_GROUP: string;
            CREATE_GROUP: string;
            SHARED_MEDIA: string;
            VIDEO_CALL: string;
            AUDIO_CALL: string;
            LOADING: string;
            REPLY: string;
            REPLIES: string;
            LAUNCH: string;
            SHARED_COLLABORATIVE_DOCUMENT: string;
            SHARED_COLLABORATIVE_WHITEBOARD: string;
            CREATED_WHITEBOARD: string;
            CREATED_DOCUMENT: string;
            PHOTOS: string;
            VIDEOS: string;
            DOCUMENT: string;
            YOU_DELETED_THIS_MESSAGE: string;
            THIS_MESSAGE_DELETED: string;
            VIEW_ON_YOUTUBE: string;
            SEARCH: string;
            NO_USERS_FOUND: string;
            ERROR: string;
            NO_GROUPS_FOUND: string;
            NO_CHATS_FOUND: string;
            MEDIA_MESSAGE: string;
            INCOMING_AUDIO_CALL: string;
            INCOMING_VIDEO_CALL: string;
            DECLINE: string;
            ACCEPT: string;
            CALL_INITIATED: string; /**
             * Needs to be called at the start of the application in order to set the language
             * @param {Object} - language & resources
             */
            OUTGOING_AUDIO_CALL: string;
            OUTGOING_VIDEO_CALL: string;
            CALL_REJECTED: string;
            REJECTED_CALL: string;
            CALL_ACCEPTED: string;
            JOINED: string;
            LEFT_THE_CALL: string;
            UNANSWERED_AUDIO_CALL: string;
            UNANSWERED_VIDEO_CALL: string;
            CALL_ENDED: string;
            CALL_CANCELLED: string;
            CALL_BUSY: string;
            CALLING: string;
            ADD: string;
            NO_BANNED_MEMBERS_FOUND: string;
            BANNED_MEMBERS: string;
            NAME: string;
            SCOPE: string;
            UNBAN: string;
            SELECT_GROUP_TYPE: string;
            ENTER_GROUP_PASSWORD: string;
            CREATE: string;
            CREATE_POLL: string;
            QUESTION: string;
            ENTER_YOUR_QUESTION: string;
            OPTIONS: string;
            ENTER_YOUR_OPTION: string;
            ADD_NEW_OPTION: string;
            VIEW_MEMBERS: string;
            DETAILS: string;
            NOTIFICATIONS: string;
            OTHER: string;
            HELP: string;
            REPORT_PROBLEM: string;
            GROUP_MEMBERS: string; /**
             * Returns the native language
             * @returns {String} native langauge i.e. en-US
             */
            BAN: string;
            KICK: string;
            PICK_YOUR_EMOJI: string;
            PRIVATE_GROUP: string;
            PROTECTED_GROUP: string;
            VISIT: string;
            ATTACH: string;
            ATTACH_FILE: string;
            ATTACH_VIDEO: string;
            ATTACH_AUDIO: string;
            ATTACH_IMAGE: string;
            COLLABORATE_USING_DOCUMENT: string;
            COLLABORATE_USING_WHITEBOARD: string;
            EMOJI: string;
            ENTER_YOUR_MESSAGE_HERE: string;
            NO_MESSAGES_FOUND: string;
            THREAD: string;
            COLLABORATIVE_DOCUMENT: string;
            COLLABORATIVE_WHITEBOARD: string;
            ADD_REACTION: string;
            NO_STICKERS_FOUND: string;
            REPLY_TO_THREAD: string;
            REPLY_IN_THREAD: string;
            DELETE_MESSAGE: string;
            EDIT_MESSAGE: string;
            SUNDAY: string;
            MONDAY: string;
            TUESDAY: string;
            WEDNESDAY: string;
            THURSDAY: string;
            FRIDAY: string;
            SATURDAY: string;
            OWNER: string;
            CHANGE_SCOPE: string;
            STICKER: string;
            LAST_ACTIVE_AT: string;
            VOICE_CALL: string;
            VIEW_DETAIL: string;
            VOTES: string;
            VOTE: string;
            NO_VOTE: string;
            REACTED: string;
            ADDED: string;
            UNBANNED: string;
            MADE: string;
            CALL_UNANSWERED: string;
            MISSED_AUDIO_CALL: string;
            ENTER_YOUR_PASSWORD: string;
            DOCS: string;
            NO_RECORDS_FOUND: string;
            LIVE_REACTION: string;
            SMILEY_PEOPLE: string;
            ANIMALES_NATURE: string;
            FOOD_DRINK: string;
            ACTIVITY: string;
            TRAVEL_PLACES: string;
            OBJECTS: string;
            SYMBOLS: string;
            FLAGS: string;
            SENT: string;
            SEEN: string;
            DELIVERED: string;
            TRANSLATE_MESSAGE: string;
            LEFT: string;
            KICKED: string;
            BANNED: string;
            NEW_MESSAGES: string;
            NEW_MESSAGE: string;
            JUMP: string;
            SELECT_VIDEO_SOURCE: string;
            SELECT_INPUT_AUDIO_SOURCE: string;
            SELECT_OUTPUT_AUDIO_SOURCE: string;
            INITIATED_GROUP_CALL: string;
            YOU_INITIATED_GROUP_CALL: string;
            IGNORE: string;
            ON_ANOTHER_CALL: string;
            CREATING: string;
            AVATAR: string;
            GROUP_NAME_BLANK: string;
            GROUP_TYPE_BLANK: string;
            GROUP_PASSWORD_BLANK: string;
            POLL_QUESTION_BLANK: string;
            POLL_OPTION_BLANK: string;
            ONGOING_CALL: string;
            YOU_ALREADY_ONGOING_CALL: string;
            RESIZE: string;
            SETTINGS: string;
            ACTIONS: string;
            VIEW_PROFILE: string;
            SEND_MESSAGE_IN_PRIVATE: string;
            DELETE: string;
            DELETE_CONFIRM: string;
            CANCEL: string;
            LEAVE_CONFIRM: string;
            TRANSFER_CONFIRM: string;
            ADDING: string;
            TRANSFER: string;
            TRANSFERRING: string;
            YES: string;
            NO: string;
            SOMETHING_WRONG: string;
            INVALID_GROUP_NAME: string;
            INVALID_GROUP_TYPE: string;
            INVALID_PASSWORD: string;
            WRONG_PASSWORD: string;
            INVALID_POLL_QUESTION: string;
            INVALID_POLL_OPTION: string;
            SAME_LANGUAGE_MESSAGE: string;
            LEAVE: string;
            CALLS: string;
            CUSTOM_MESSAGE_LOCATION: string;
            OFFLINE: string;
            YOU: string;
            PRIVACY: string;
            BLOCKED_USERS: string;
            "YOU'VE_BLOCKED": string;
            NO_PHOTOS: string;
            NO_VIDEOS: string;
            NO_DOCUMENTS: string;
            JOIN: string;
            DELETE_CONFIRM_MESSAGE: string;
            CHAT_ERROR_MESSAGE: string;
            TRY_AGAIN: string;
            CONFIRM: string;
            UNSAFE_CONTENT: string;
            UNSAFE_CONFIRMATION: string;
            AUDIO_FILE: string;
            SHARED_FILE: string;
            OPEN_DOCUMENT: string;
            OPEN_WHITEBOARD: string;
            PEOPLE_VOTED: string;
            ADD_TO_CHAT: string;
            TAKE_PHOTO: string;
            SET_THE_ANSWERS: string;
            ADD_ANOTHER_ANSWER: string;
            ANSWER: string;
            IN_A_THREAD: string;
            ERROR_GROUP_CREATE: string;
            TRY_AGAIN_LATER: string;
            CONTINUE: string;
            GROUP_NAME_MAX: string;
            PASSWORD_MAX: string;
            GROUP_PASSWORD: string;
            INCORRECT_PASSWORD: string;
            OPEN_WHITEBOARD_TO_DRAW: string;
            CALL_HISTORY: string;
            NO_CALL_HISTORY: string;
            CALL_DETAILS: string;
            CONFERENCE_CALL: string;
            NEW_GROUP: string;
            TRANSFER_OWNERSHIP: string;
            COPY_MESSAGE: string;
            SHARE: string;
            OPEN_DOCUMENT_TO_DRAW: string;
            INFORMATION: string;
            COPY_TEXT: string;
            FORWARD: string;
            TEXT: string;
            INCOMING_CALL: string;
            OUTGOING_CALL: string;
            CALL_MISSED: string;
            NEW_CONVERSATION: string;
            FORWARDING: string;
            READ: string;
            No_RECIPIENT: string;
            RECEIPT_INFORMATION: string;
            MESSAGE: string;
        };
        sv: {
            USERS: string;
            CHATS: string;
            GROUPS: string;
            MORE: string;
            MESSAGE_IMAGE: string;
            MESSAGE_FILE: string;
            MESSAGE_VIDEO: string;
            MESSAGE_AUDIO: string;
            CUSTOM_MESSAGE: string;
            MISSED_VOICE_CALL: string;
            MISSED_VIDEO_CALL: string;
            CUSTOM_MESSAGE_POLL: string;
            CUSTOM_MESSAGE_STICKER: string;
            CUSTOM_MESSAGE_DOCUMENT: string;
            CUSTOM_MESSAGE_WHITEBOARD: string;
            ONLINE: string;
            ADMINISTRATOR: string;
            MODERATOR: string;
            PARTICIPANT: string;
            PUBLIC: string;
            PRIVATE: string;
            PASSWORD_PROTECTED: string;
            PRIVACY_AND_SECURITY: string;
            PREFERENCES: string;
            MEMBERS: string;
            TODAY: string;
            YESTERDAY: string;
            SUNDAY: string;
            MONDAY: string;
            TUESDAY: string;
            WEDNESDAY: string;
            THURSDAY: string;
            FRIDAY: string;
            SATURDAY: string;
            TYPING: string;
            IS_TYPING: string;
            CLOSE: string;
            ENTER_GROUP_NAME: string; /**Properties and constants */
            ADD_MEMBERS: string;
            SEND_MESSAGE: string;
            UNBLOCK_USER: string;
            BLOCK_USER: string;
            DELETE_AND_EXIT: string;
            LEAVE_GROUP: string;
            CREATE_GROUP: string;
            SHARED_MEDIA: string;
            VIDEO_CALL: string;
            AUDIO_CALL: string;
            LOADING: string;
            REPLY: string;
            REPLIES: string;
            LAUNCH: string;
            SHARED_COLLABORATIVE_DOCUMENT: string;
            SHARED_COLLABORATIVE_WHITEBOARD: string;
            CREATED_WHITEBOARD: string;
            CREATED_DOCUMENT: string;
            PHOTOS: string;
            VIDEOS: string;
            DOCUMENT: string;
            YOU_DELETED_THIS_MESSAGE: string;
            THIS_MESSAGE_DELETED: string;
            VIEW_ON_YOUTUBE: string;
            SEARCH: string;
            NO_USERS_FOUND: string; /**Add to the original array of translations if language code is not found */
            ERROR: string;
            NO_GROUPS_FOUND: string;
            NO_CHATS_FOUND: string;
            MEDIA_MESSAGE: string;
            INCOMING_AUDIO_CALL: string;
            INCOMING_VIDEO_CALL: string;
            DECLINE: string;
            ACCEPT: string;
            CALL_INITIATED: string;
            OUTGOING_AUDIO_CALL: string;
            OUTGOING_VIDEO_CALL: string;
            CALL_REJECTED: string;
            REJECTED_CALL: string;
            CALL_ACCEPTED: string;
            JOINED: string;
            LEFT_THE_CALL: string;
            UNANSWERED_AUDIO_CALL: string;
            UNANSWERED_VIDEO_CALL: string;
            CALL_ENDED: string;
            CALL_CANCELLED: string;
            CALL_BUSY: string;
            CALLING: string;
            ADD: string;
            NO_BANNED_MEMBERS_FOUND: string;
            BANNED_MEMBERS: string;
            NAME: string;
            SCOPE: string;
            UNBAN: string;
            SELECT_GROUP_TYPE: string;
            ENTER_GROUP_PASSWORD: string;
            CREATE: string;
            CREATE_POLL: string;
            QUESTION: string;
            ENTER_YOUR_QUESTION: string;
            OPTIONS: string;
            ENTER_YOUR_OPTION: string;
            ADD_NEW_OPTION: string;
            VIEW_MEMBERS: string;
            DETAILS: string;
            NOTIFICATIONS: string;
            OTHER: string;
            HELP: string;
            REPORT_PROBLEM: string;
            GROUP_MEMBERS: string;
            BAN: string;
            KICK: string;
            PICK_YOUR_EMOJI: string;
            PRIVATE_GROUP: string;
            PROTECTED_GROUP: string;
            VISIT: string;
            ATTACH: string;
            ATTACH_FILE: string;
            ATTACH_VIDEO: string;
            ATTACH_AUDIO: string;
            ATTACH_IMAGE: string;
            COLLABORATE_USING_DOCUMENT: string;
            COLLABORATE_USING_WHITEBOARD: string;
            EMOJI: string;
            ENTER_YOUR_MESSAGE_HERE: string;
            NO_MESSAGES_FOUND: string;
            THREAD: string;
            COLLABORATIVE_DOCUMENT: string;
            COLLABORATIVE_WHITEBOARD: string;
            ADD_REACTION: string;
            NO_STICKERS_FOUND: string;
            REPLY_TO_THREAD: string;
            REPLY_IN_THREAD: string;
            DELETE_MESSAGE: string;
            EDIT_MESSAGE: string;
            OWNER: string;
            CHANGE_SCOPE: string;
            STICKER: string;
            LAST_ACTIVE_AT: string;
            VOICE_CALL: string;
            VIEW_DETAIL: string;
            VOTES: string;
            VOTE: string;
            NO_VOTE: string;
            REACTED: string;
            ADDED: string;
            UNBANNED: string;
            MADE: string;
            CALL_UNANSWERED: string;
            MISSED_AUDIO_CALL: string;
            ENTER_YOUR_PASSWORD: string;
            DOCS: string;
            NO_RECORDS_FOUND: string;
            LIVE_REACTION: string;
            SMILEY_PEOPLE: string;
            ANIMALES_NATURE: string;
            FOOD_DRINK: string;
            ACTIVITY: string;
            TRAVEL_PLACES: string;
            OBJECTS: string;
            SYMBOLS: string;
            FLAGS: string;
            SENT: string;
            SEEN: string;
            DELIVERED: string;
            TRANSLATE_MESSAGE: string;
            LEFT: string;
            KICKED: string;
            BANNED: string;
            NEW_MESSAGES: string;
            NEW_MESSAGE: string;
            JUMP: string;
            SELECT_VIDEO_SOURCE: string;
            SELECT_INPUT_AUDIO_SOURCE: string;
            SELECT_OUTPUT_AUDIO_SOURCE: string;
            INITIATED_GROUP_CALL: string;
            YOU_INITIATED_GROUP_CALL: string;
            IGNORE: string;
            ON_ANOTHER_CALL: string;
            CREATING: string;
            AVATAR: string;
            GROUP_NAME_BLANK: string;
            GROUP_TYPE_BLANK: string;
            GROUP_PASSWORD_BLANK: string;
            POLL_QUESTION_BLANK: string;
            POLL_OPTION_BLANK: string;
            ONGOING_CALL: string;
            YOU_ALREADY_ONGOING_CALL: string;
            RESIZE: string;
            SETTINGS: string;
            ACTIONS: string;
            VIEW_PROFILE: string;
            SEND_MESSAGE_IN_PRIVATE: string;
            DELETE: string;
            DELETE_CONFIRM: string;
            CANCEL: string;
            LEAVE_CONFIRM: string;
            TRANSFER_CONFIRM: string;
            ADDING: string;
            TRANSFER: string;
            TRANSFERRING: string;
            YES: string;
            NO: string;
            SOMETHING_WRONG: string;
            INVALID_GROUP_NAME: string;
            INVALID_GROUP_TYPE: string;
            INVALID_PASSWORD: string;
            WRONG_PASSWORD: string;
            INVALID_POLL_QUESTION: string;
            INVALID_POLL_OPTION: string;
            SAME_LANGUAGE_MESSAGE: string;
            LEAVE: string;
            CALLS: string;
            CUSTOM_MESSAGE_LOCATION: string;
            OFFLINE: string;
            YOU: string;
            PRIVACY: string;
            BLOCKED_USERS: string;
            "YOU'VE_BLOCKED": string;
            NO_PHOTOS: string;
            NO_VIDEOS: string;
            NO_DOCUMENTS: string;
            JOIN: string;
            DELETE_CONFIRM_MESSAGE: string;
            CHAT_ERROR_MESSAGE: string;
            TRY_AGAIN: string;
            CONFIRM: string;
            UNSAFE_CONTENT: string;
            UNSAFE_CONFIRMATION: string;
            AUDIO_FILE: string;
            SHARED_FILE: string;
            OPEN_DOCUMENT: string;
            OPEN_WHITEBOARD: string;
            PEOPLE_VOTED: string;
            ADD_TO_CHAT: string;
            TAKE_PHOTO: string;
            SET_THE_ANSWERS: string;
            ADD_ANOTHER_ANSWER: string;
            ANSWER: string;
            IN_A_THREAD: string;
            ERROR_GROUP_CREATE: string;
            TRY_AGAIN_LATER: string;
            CONTINUE: string;
            GROUP_NAME_MAX: string;
            PASSWORD_MAX: string;
            GROUP_PASSWORD: string;
            INCORRECT_PASSWORD: string;
            OPEN_WHITEBOARD_TO_DRAW: string;
            CALL_HISTORY: string;
            NO_CALL_HISTORY: string;
            CALL_DETAILS: string;
            CONFERENCE_CALL: string;
            NEW_GROUP: string;
            TRANSFER_OWNERSHIP: string;
            COPY_MESSAGE: string;
            SHARE: string;
            OPEN_DOCUMENT_TO_DRAW: string;
            INFORMATION: string;
            COPY_TEXT: string;
            FORWARD: string;
            TEXT: string;
            INCOMING_CALL: string;
            OUTGOING_CALL: string;
            CALL_MISSED: string;
            NEW_CONVERSATION: string;
            FORWARDING: string;
            READ: string;
            No_RECIPIENT: string;
            RECEIPT_INFORMATION: string;
            MESSAGE: string;
        };
        lt: {
            USERS: string;
            CHATS: string;
            GROUPS: string;
            MORE: string;
            MESSAGE_IMAGE: string;
            MESSAGE_FILE: string;
            MESSAGE_VIDEO: string;
            MESSAGE_AUDIO: string;
            CUSTOM_MESSAGE: string;
            MISSED_VOICE_CALL: string;
            MISSED_VIDEO_CALL: string;
            CUSTOM_MESSAGE_POLL: string;
            CUSTOM_MESSAGE_STICKER: string;
            CUSTOM_MESSAGE_DOCUMENT: string;
            CUSTOM_MESSAGE_WHITEBOARD: string;
            ONLINE: string;
            ADMINISTRATOR: string;
            MODERATOR: string;
            PARTICIPANT: string;
            PUBLIC: string;
            PRIVATE: string;
            PASSWORD_PROTECTED: string;
            PRIVACY_AND_SECURITY: string;
            PREFERENCES: string;
            MEMBERS: string;
            TODAY: string;
            YESTERDAY: string;
            SUNDAY: string;
            MONDAY: string;
            TUESDAY: string;
            WEDNESDAY: string;
            THURSDAY: string;
            FRIDAY: string;
            SATURDAY: string;
            TYPING: string;
            IS_TYPING: string;
            CLOSE: string;
            ENTER_GROUP_NAME: string;
            ADD_MEMBERS: string;
            SEND_MESSAGE: string;
            UNBLOCK_USER: string;
            BLOCK_USER: string;
            DELETE_AND_EXIT: string;
            LEAVE_GROUP: string;
            CREATE_GROUP: string;
            SHARED_MEDIA: string;
            VIDEO_CALL: string;
            AUDIO_CALL: string;
            LOADING: string;
            REPLY: string;
            REPLIES: string;
            LAUNCH: string;
            SHARED_COLLABORATIVE_DOCUMENT: string;
            SHARED_COLLABORATIVE_WHITEBOARD: string;
            CREATED_WHITEBOARD: string;
            CREATED_DOCUMENT: string;
            PHOTOS: string;
            VIDEOS: string;
            DOCUMENT: string;
            YOU_DELETED_THIS_MESSAGE: string;
            THIS_MESSAGE_DELETED: string;
            VIEW_ON_YOUTUBE: string;
            SEARCH: string;
            NO_USERS_FOUND: string;
            ERROR: string;
            NO_GROUPS_FOUND: string;
            NO_CHATS_FOUND: string;
            MEDIA_MESSAGE: string;
            INCOMING_AUDIO_CALL: string;
            INCOMING_VIDEO_CALL: string;
            DECLINE: string;
            ACCEPT: string;
            CALL_INITIATED: string;
            OUTGOING_AUDIO_CALL: string;
            OUTGOING_VIDEO_CALL: string;
            CALL_REJECTED: string;
            REJECTED_CALL: string;
            CALL_ACCEPTED: string;
            JOINED: string;
            LEFT_THE_CALL: string;
            UNANSWERED_AUDIO_CALL: string;
            UNANSWERED_VIDEO_CALL: string;
            CALL_ENDED: string;
            CALL_CANCELLED: string;
            CALL_BUSY: string;
            CALLING: string;
            ADD: string;
            NO_BANNED_MEMBERS_FOUND: string;
            BANNED_MEMBERS: string;
            NAME: string;
            SCOPE: string;
            UNBAN: string;
            SELECT_GROUP_TYPE: string;
            ENTER_GROUP_PASSWORD: string;
            CREATE: string;
            CREATE_POLL: string;
            QUESTION: string;
            ENTER_YOUR_QUESTION: string;
            OPTIONS: string;
            ENTER_YOUR_OPTION: string;
            ADD_NEW_OPTION: string;
            VIEW_MEMBERS: string;
            DETAILS: string;
            NOTIFICATIONS: string;
            OTHER: string;
            HELP: string;
            REPORT_PROBLEM: string;
            GROUP_MEMBERS: string;
            BAN: string;
            KICK: string;
            PICK_YOUR_EMOJI: string;
            PRIVATE_GROUP: string;
            PROTECTED_GROUP: string;
            VISIT: string;
            ATTACH: string;
            ATTACH_FILE: string;
            ATTACH_VIDEO: string;
            ATTACH_AUDIO: string;
            ATTACH_IMAGE: string;
            COLLABORATE_USING_DOCUMENT: string;
            COLLABORATE_USING_WHITEBOARD: string;
            EMOJI: string;
            ENTER_YOUR_MESSAGE_HERE: string;
            NO_MESSAGES_FOUND: string;
            THREAD: string;
            COLLABORATIVE_DOCUMENT: string;
            COLLABORATIVE_WHITEBOARD: string;
            ADD_REACTION: string;
            NO_STICKERS_FOUND: string;
            REPLY_TO_THREAD: string;
            REPLY_IN_THREAD: string;
            DELETE_MESSAGE: string;
            EDIT_MESSAGE: string;
            OWNER: string;
            CHANGE_SCOPE: string;
            STICKER: string;
            LAST_ACTIVE_AT: string;
            VOICE_CALL: string;
            VIEW_DETAIL: string;
            VOTES: string;
            VOTE: string;
            /**
             * Returns true if the active language is rtl otherwise return false
             * @returns {Boolean} whether the language is rtl or not
             */
            NO_VOTE: string;
            REACTED: string;
            ADDED: string;
            UNBANNED: string;
            MADE: string;
            CALL_UNANSWERED: string;
            MISSED_AUDIO_CALL: string;
            ENTER_YOUR_PASSWORD: string;
            DOCS: string;
            NO_RECORDS_FOUND: string;
            LIVE_REACTION: string;
            SMILEY_PEOPLE: string;
            ANIMALES_NATURE: string;
            FOOD_DRINK: string;
            ACTIVITY: string;
            TRAVEL_PLACES: string;
            OBJECTS: string;
            SYMBOLS: string;
            FLAGS: string;
            SENT: string;
            SEEN: string;
            DELIVERED: string;
            TRANSLATE_MESSAGE: string;
            LEFT: string;
            KICKED: string;
            BANNED: string;
            NEW_MESSAGES: string;
            NEW_MESSAGE: string;
            JUMP: string;
            SELECT_VIDEO_SOURCE: string;
            SELECT_INPUT_AUDIO_SOURCE: string;
            SELECT_OUTPUT_AUDIO_SOURCE: string;
            INITIATED_GROUP_CALL: string;
            YOU_INITIATED_GROUP_CALL: string;
            IGNORE: string;
            ON_ANOTHER_CALL: string;
            CREATING: string;
            AVATAR: string;
            GROUP_NAME_BLANK: string;
            GROUP_TYPE_BLANK: string;
            GROUP_PASSWORD_BLANK: string;
            POLL_QUESTION_BLANK: string;
            POLL_OPTION_BLANK: string;
            ONGOING_CALL: string;
            YOU_ALREADY_ONGOING_CALL: string;
            RESIZE: string;
            SETTINGS: string;
            ACTIONS: string;
            VIEW_PROFILE: string;
            SEND_MESSAGE_IN_PRIVATE: string;
            DELETE: string;
            DELETE_CONFIRM: string;
            CANCEL: string;
            LEAVE_CONFIRM: string;
            TRANSFER_CONFIRM: string;
            ADDING: string;
            TRANSFER: string;
            TRANSFERRING: string;
            YES: string;
            NO: string;
            SOMETHING_WRONG: string;
            INVALID_GROUP_NAME: string;
            INVALID_GROUP_TYPE: string;
            INVALID_PASSWORD: string;
            WRONG_PASSWORD: string;
            INVALID_POLL_QUESTION: string;
            INVALID_POLL_OPTION: string;
            SAME_LANGUAGE_MESSAGE: string;
            LEAVE: string;
            CALLS: string;
            CUSTOM_MESSAGE_LOCATION: string;
            OFFLINE: string;
            YOU: string;
            PRIVACY: string;
            BLOCKED_USERS: string;
            "YOU'VE_BLOCKED": string;
            NO_PHOTOS: string;
            NO_VIDEOS: string;
            NO_DOCUMENTS: string;
            JOIN: string;
            DELETE_CONFIRM_MESSAGE: string;
            CHAT_ERROR_MESSAGE: string;
            TRY_AGAIN: string;
            CONFIRM: string;
            UNSAFE_CONTENT: string;
            UNSAFE_CONFIRMATION: string;
            AUDIO_FILE: string;
            SHARED_FILE: string;
            OPEN_DOCUMENT: string;
            OPEN_WHITEBOARD: string;
            PEOPLE_VOTED: string;
            ADD_TO_CHAT: string;
            TAKE_PHOTO: string;
            SET_THE_ANSWERS: string;
            ADD_ANOTHER_ANSWER: string;
            ANSWER: string;
            IN_A_THREAD: string;
            ERROR_GROUP_CREATE: string;
            TRY_AGAIN_LATER: string;
            CONTINUE: string;
            GROUP_NAME_MAX: string;
            PASSWORD_MAX: string;
            GROUP_PASSWORD: string;
            INCORRECT_PASSWORD: string;
            OPEN_WHITEBOARD_TO_DRAW: string;
            CALL_HISTORY: string;
            NO_CALL_HISTORY: string;
            CALL_DETAILS: string;
            CONFERENCE_CALL: string;
            NEW_GROUP: string;
            TRANSFER_OWNERSHIP: string;
            COPY_MESSAGE: string;
            SHARE: string;
            OPEN_DOCUMENT_TO_DRAW: string;
            INFORMATION: string;
            COPY_TEXT: string;
            FORWARD: string;
            TEXT: string;
            INCOMING_CALL: string;
            OUTGOING_CALL: string;
            CALL_MISSED: string;
            NEW_CONVERSATION: string;
            FORWARDING: string;
            READ: string;
            No_RECIPIENT: string;
            RECEIPT_INFORMATION: string;
            MESSAGE: string;
        };
    };
    /**
     * Needs to be called at the start of the application in order to set the language
     * @param {Object} - language & resources
     */
    static init: ({ language, resources }: {
        language: any;
        resources: any;
    }) => void;
    /**
     * Returns the native language
     * @returns {String} native langauge i.e. en-US
     */
    static getNativeLanguage: () => any;
    /**
     * Returns the language code
     * @returns {String} language code i.e. en
     */
    static getLanguageCode: () => any;
    /**
     * Returns the active language. Return fallback language if translation is not available for the active language
     * @returns {String} active language
     */
    static getLocale: () => any;
    /**
     * Set the active language
     * @param {String} language
     */
    static setLocale: (language: any) => void;
    /**
     * Accepts the string to localize and return the localized string
     * @param {String} str
     * @returns {String} localized str
     */
    static localize(str: any): any;
    /**
     * Sets the default lannguage if no language is passed in init method
     */
    static setDefaultLanguage: () => void;
    /**
     * Returns true if the active language is rtl otherwise return false
     * @returns {Boolean} whether the language is rtl or not
     */
    static isRTL: () => boolean;
    /**
     * Returns rtl or ltr based on the active language
     * @returns {String} the direction of the active langauge
     */
    static getDir: () => "ltr" | "rtl";
}
/**
 * Returns localized string based on active language
 * @param {String} str
 * @returns {String} localized str
 */
declare const localize: (str: any) => any;
export { CometChatLocalize, localize };
